/* Include statements */

#include "udf.h"
#include "granular.h"
#include "sg_mphase.h"

#define PI 3.14159265358979323846264

/************************************************************************
Change the following parameters:
corinp=Input (intrinsic) coefficient of restitution
rhop= Solids density
rhog= gas density
d_one= singlet diameter
d_two= doublet diameter
d_three= tripet diameter
d_four= quadruplet diameter
d_five= quintet diameter

-----------------------------------------------------------------------------
Degrees of freedom=6 for everything larger than doublet.
Degrees of freedom=5 for doublet.
Degrees of freedom=3 for singlet.

-----------------------------------------------------------------------------
dPdY=weight of system (N/m^3)

All units SI
*************************************************************************/
#define nrect 100.0

#define corinp 0.97
#define rhop 2500.0
#define d_one 64.0E-6

/*The following are manually calculated!*/
#define d_two 80.6349472E-6
#define d_three 92.3039725E-6
#define d_four 101.593667E-6
#define d_five 109.438461E-6

#define m_one 3.43145694E-10
#define m_two 6.86291387E-10
#define m_three 10.2943708E-10
#define m_four 13.7258277E-10
#define m_five 17.1572847E-10

#define v_crit_a_one_one 0.00838
#define v_crit_a_one_two 0.015449
#define v_crit_a_one_three 0.01653
#define v_crit_a_one_four 0.01742

#define v_crit_a_two_two 0.014502
#define v_crit_a_two_three 0.014692

#define v_crit_a_high 0.006644

#define v_crit_b_one_two 0.000147
#define v_crit_b_one_three 0.000147
#define v_crit_b_one_four 0.000147
#define v_crit_b_one_five 0.000147

#define v_crit_b_two_two 0.000147
#define v_crit_b_two_three 0.000147
#define v_crit_b_two_four 0.000147
#define v_crit_b_two_five 0.000147

#define v_crit_b_three_three 0.000147
#define v_crit_b_three_four 0.000147
#define v_crit_b_three_five 0.000147

#define v_crit_b_four_four 0.000147
#define v_crit_b_four_five 0.000147

#define v_crit_b_five_five 0.000147

#define d_one_one 64.0E-6
#define d_one_two 8.9331e-5
#define d_one_three 10.1415e-5
#define d_one_four 11.3426e-5
#define d_one_five 12.6863e-5

#define d_two_two 8.9493e-5
#define d_two_three 15.5016e-5
#define d_two_four 19.514e-5
#define d_two_five 18.9287e-5

#define d_three_three 12.4625e-5
#define d_three_four 25.5828e-5
#define d_three_five 24.0222e-5

#define d_four_four 2.56-4
#define d_four_five 2.88e-4

#define d_five_five 3.2e-4

/*NOTE: This script requires XX user defined memory locations to be defined (User-Defined->Memory...->Number of User Defined Memory Locations).

They are as follows:


NOTE: Need to specify DEFINE_ADJUST:
User-Defined-> Function Hooks...->Edit the Adjust line

dPdY=weight of system (N/m^3)

*/

#define ph_1_id 1
#define ph_2_id 2
#define ph_3_id 3
#define ph_4_id 4
#define ph_5_id 5

/*Manually enter dPdy. It is equal to:
9.81*Sum(Vol. fraction phase n * Material density phase n, for all phases n)
(Sum product of volume fraction and material density over all phases, including gas phase and solids phase).*/
#define dPdY 438.5366753

/***********************************************************************
UDFs for specifying IA05 
(Hrenya Group via Kevin M. Kellogg)
************************************************************************/

DEFINE_ADJUST(IA05,domain)
{
	real dof_over_d_sum;
	real n_one, n_two, n_three, n_four, n_five;
	real N_one_one, N_one_two, N_one_three, N_one_four, N_one_five, N_two_one, N_two_two, N_two_three, N_two_four, N_two_five, N_three_one, N_three_two, N_three_three, N_three_four, N_three_five, N_four_one, N_four_two, N_four_three, N_four_four, N_four_five, N_five_one, N_five_two, N_five_three, N_five_four, N_five_five;
	real e_one_one, e_one_two, e_one_three, e_one_four, e_one_five, e_two_two, e_two_three, e_two_four, e_two_five, e_three_three, e_three_four, e_three_five, e_four_four, e_four_five, e_five_five;
	real theta_one, theta_two, theta_three, theta_four, theta_five;
	real P_one_k, P_two_k, P_three_k, P_four_k, P_five_k;
	real P_one, P_two, P_three, P_four, P_five;
	real P_one_one_c, P_one_two_c, P_one_three_c, P_one_four_c, P_one_five_c, P_two_two_c, P_two_three_c, P_two_four_c, P_two_five_c, P_three_three_c, P_three_four_c, P_three_five_c, P_four_four_c, P_four_five_c, P_five_five_c;
	real P_one_c, P_two_c, P_three_c, P_four_c, P_five_c;
	real A_one_one, A_one_two, A_one_three, A_one_four, A_one_five, A_two_two, A_two_three, A_two_four, A_two_five, A_three_three, A_three_four, A_three_five, A_four_four, A_four_five, A_five_five;
	real B_one_two, B_one_three, B_one_four, B_one_five, B_two_one, B_two_three, B_two_four, B_two_five, B_three_one, B_three_two, B_three_four, B_three_five, B_four_one, B_four_two, B_four_three, B_four_five, B_five_one, B_five_two, B_five_three, B_five_four;
	real D_one_one, D_one_two, D_one_three, D_one_four, D_one_five, D_two_two, D_two_three, D_two_four, D_two_five, D_three_three, D_three_four, D_three_five, D_four_four, D_four_five, D_five_five;
	real R_zero_one_one, R_zero_one_two, R_zero_one_three, R_zero_one_four, R_zero_one_five, R_zero_two_two, R_zero_two_three, R_zero_two_four, R_zero_two_five, R_zero_three_three, R_zero_three_four, R_zero_three_five, R_zero_four_four, R_zero_four_five, R_zero_five_five;
	real R_one_one_one, R_one_one_two, R_one_one_three, R_one_one_four, R_one_one_five, R_one_two_two, R_one_two_three, R_one_two_four, R_one_two_five, R_one_three_three, R_one_three_four, R_one_three_five, R_one_four_four, R_one_four_five, R_one_five_five;
	real R_two_one_one, R_two_one_two, R_two_one_three, R_two_one_four, R_two_one_five, R_two_two_two, R_two_two_three, R_two_two_four, R_two_two_five, R_two_three_three, R_two_three_four, R_two_three_five, R_two_four_four, R_two_four_five, R_two_five_five;
	
	/*real R_three_one_one, R_three_one_two, R_three_one_three, R_three_one_four, R_three_one_five, R_three_two_two, R_three_two_three, R_three_two_four, R_three_two_five, R_three_three_three, R_three_three_four, R_three_three_five, R_three_four_four, R_three_four_five, R_three_five_five;
	real R_four_one_one, R_four_one_two, R_four_one_three, R_four_one_four, R_four_one_five, R_four_two_two, R_four_two_three, R_four_two_four, R_four_two_five, R_four_three_three, R_four_three_four, R_four_three_five, R_four_four_four, R_four_four_five, R_four_five_five;
	*/
	real R_five_one_one, R_five_one_two, R_five_one_three, R_five_one_four, R_five_one_five, R_five_two_two, R_five_two_three, R_five_two_four, R_five_two_five, R_five_three_three, R_five_three_four, R_five_three_five, R_five_four_four, R_five_four_five, R_five_five_five;
	
	/*real R_six_one_one, R_six_one_two, R_six_one_three, R_six_one_four, R_six_one_five, R_six_two_two, R_six_two_three, R_six_two_four, R_six_two_five, R_six_three_three, R_six_three_four, R_six_three_five, R_six_four_four, R_six_four_five, R_six_five_five;
	real R_seven_one_one, R_seven_one_two, R_seven_one_three, R_seven_one_four, R_seven_one_five, R_seven_two_two, R_seven_two_three, R_seven_two_four, R_seven_two_five, R_seven_three_three, R_seven_three_four, R_seven_three_five, R_seven_four_four, R_seven_four_five, R_seven_five_five;
	real R_eight_one_one, R_eight_one_two, R_eight_one_three, R_eight_one_four, R_eight_one_five, R_eight_two_two, R_eight_two_three, R_eight_two_four, R_eight_two_five, R_eight_three_three, R_eight_three_four, R_eight_three_five, R_eight_four_four, R_eight_four_five, R_eight_five_five;
	real R_nine_one_one, R_nine_one_two, R_nine_one_three, R_nine_one_four, R_nine_one_five, R_nine_two_two, R_nine_two_three, R_nine_two_four, R_nine_two_five, R_nine_three_three, R_nine_three_four, R_nine_three_five, R_nine_four_four, R_nine_four_five, R_nine_five_five;
	real R_ten_one_one, R_ten_one_two, R_ten_one_three, R_ten_one_four, R_ten_one_five, R_ten_two_two, R_ten_two_three, R_ten_two_four, R_ten_two_five, R_ten_three_three, R_ten_three_four, R_ten_three_five, R_ten_four_four, R_ten_four_five, R_ten_five_five;
	*/
	real g_one_one, g_one_two, g_one_three, g_one_four, g_one_five, g_two_two, g_two_three, g_two_four, g_two_five, g_three_three, g_three_four, g_three_five, g_four_four, g_four_five, g_five_five;
	real g_ii_one_one, g_ii_one_two, g_ii_one_three, g_ii_one_four, g_ii_one_five, g_ii_two_one, g_ii_two_two, g_ii_two_three, g_ii_two_four, g_ii_two_five, g_ii_three_one, g_ii_three_two, g_ii_three_three, g_ii_three_four, g_ii_three_five, g_ii_four_one, g_ii_four_two, g_ii_four_three, g_ii_four_four, g_ii_four_five, g_ii_five_one, g_ii_five_two, g_ii_five_three, g_ii_five_four, g_ii_five_five; 
	real N_one, N_two, N_three, N_four, N_five;
	real k_one, k_two, k_three, k_four, k_five;
	real C_Dip_one_two, C_Dip_one_three, C_Dip_one_four, C_Dip_one_five, C_Dip_two_three, C_Dip_two_four, C_Dip_two_five, C_Dip_three_four, C_Dip_three_five, C_Dip_four_five;
	real F_D_one_x, F_D_two_x, F_D_three_x, F_D_four_x, F_D_five_x;
	real F_D_one_y, F_D_two_y, F_D_three_y, F_D_four_y, F_D_five_y;
	real F_D_one_z, F_D_two_z, F_D_three_z, F_D_four_z, F_D_five_z;
	real mu_one, mu_two, mu_three, mu_four, mu_five;
	real lamda_one, lamda_two, lamda_three, lamda_four, lamda_five;
	real Lun_one, Lun_two, Lun_three, Lun_four, Lun_five;
	real Gen_one, Gen_two, Gen_three, Gen_four, Gen_five;
	real SS_one_one, SS_one_two, SS_one_three, SS_one_four, SS_one_five, SS_two_two, SS_two_three, SS_two_four, SS_two_five, SS_three_three, SS_three_four, SS_three_five, SS_four_four, SS_four_five, SS_five_five;
	real Freq_one_one, Freq_one_two, Freq_one_three, Freq_one_four, Freq_one_five, Freq_two_two, Freq_two_three, Freq_two_four, Freq_two_five, Freq_three_three, Freq_three_four, Freq_three_five, Freq_four_four, Freq_four_five, Freq_five_five;	
	real Sagg_one_one, Sagg_one_two, Sagg_one_three, Sagg_one_four, Sagg_two_two, Sagg_two_three;
	real Sbrk_one_two, Sbrk_one_three, Sbrk_one_four, Sbrk_one_five, Sbrk_two_two, Sbrk_two_three, Sbrk_two_four, Sbrk_two_five, Sbrk_three_three, Sbrk_three_four, Sbrk_three_five, Sbrk_four_four, Sbrk_four_five, Sbrk_five_five;	
	
	real M_rate_one, M_rate_two, M_rate_three, M_rate_four, M_rate_five;
	real Mom_rate_one_x, Mom_rate_two_x, Mom_rate_three_x, Mom_rate_four_x, Mom_rate_five_x;
	real Mom_rate_one_y, Mom_rate_two_y, Mom_rate_three_y, Mom_rate_four_y, Mom_rate_five_y;
	real Mom_rate_one_z, Mom_rate_two_z, Mom_rate_three_z, Mom_rate_four_z, Mom_rate_five_z;
	real vmax_one_one, vmax_one_two, vmax_one_three, vmax_one_four, vmax_one_five, vmax_two_two, vmax_two_three, vmax_two_four, vmax_two_five, vmax_three_three, vmax_three_four, vmax_three_five, vmax_four_four, vmax_four_five, vmax_five_five;
	real vn_one_one, vn_one_two, vn_one_three, vn_one_four, vn_one_five, vn_two_two, vn_two_three, vn_two_four, vn_two_five, vn_three_three, vn_three_four, vn_three_five, vn_four_four, vn_four_five, vn_five_five;
	real dv_one_one, dv_one_two, dv_one_three, dv_one_four, dv_one_five, dv_two_two, dv_two_three, dv_two_four, dv_two_five, dv_three_three, dv_three_four, dv_three_five, dv_four_four, dv_four_five, dv_five_five;
	real corsum_one_one, corsum_one_two, corsum_one_three, corsum_one_four, corsum_one_five, corsum_two_two, corsum_two_three, corsum_two_four, corsum_two_five, corsum_three_three, corsum_three_four, corsum_three_five, corsum_four_four, corsum_four_five, corsum_five_five;
	real v_crit_a_one_five, v_crit_a_two_four, v_crit_a_two_five, v_crit_a_three_three, v_crit_a_three_four, v_crit_a_three_five, v_crit_a_four_four, v_crit_a_four_five, v_crit_a_five_five;
	real i;

	Thread *thread;
	Thread *subthread_one;
	Thread *subthread_two;
	Thread *subthread_three;
	Thread *subthread_four;
	Thread *subthread_five;

	cell_t cell;

	thread_loop_c(thread,domain)
		{
		begin_c_loop(cell,thread)
			{
			subthread_one=THREAD_SUB_THREAD(thread,ph_1_id);
			subthread_two=THREAD_SUB_THREAD(thread,ph_2_id);
			subthread_three=THREAD_SUB_THREAD(thread,ph_3_id);
			subthread_four=THREAD_SUB_THREAD(thread,ph_4_id);
			subthread_five=THREAD_SUB_THREAD(thread,ph_5_id);

			theta_one=m_one*C_GT(cell,subthread_one);
			theta_two=m_two*C_GT(cell,subthread_two);
			theta_three=m_three*C_GT(cell,subthread_three);
			theta_four=m_four*C_GT(cell,subthread_four);
			theta_five=m_five*C_GT(cell,subthread_five);

			SS_one_one=3.*(C_GT(cell,subthread_one)/3.+C_GT(cell,subthread_one)/3.);
			SS_one_two=3.*(C_GT(cell,subthread_one)/3.+C_GT(cell,subthread_two)/5.);
			SS_one_three=3.*(C_GT(cell,subthread_one)/3.+C_GT(cell,subthread_three)/6.);
			SS_one_four=3.*(C_GT(cell,subthread_one)/3.+C_GT(cell,subthread_four)/6.);
			SS_one_five=3.*(C_GT(cell,subthread_one)/3.+C_GT(cell,subthread_five)/6.);

			SS_two_two=3.*(C_GT(cell,subthread_two)/5.+C_GT(cell,subthread_two)/5.);
			SS_two_three=3.*(C_GT(cell,subthread_two)/5.+C_GT(cell,subthread_three)/6.);
			SS_two_four=3.*(C_GT(cell,subthread_two)/5.+C_GT(cell,subthread_four)/6.);
			SS_two_five=3.*(C_GT(cell,subthread_two)/5.+C_GT(cell,subthread_five)/6.);

			SS_three_three=3.*(C_GT(cell,subthread_three)/6.+C_GT(cell,subthread_three)/6.);
			SS_three_four=3.*(C_GT(cell,subthread_three)/6.+C_GT(cell,subthread_four)/6.);
			SS_three_five=3.*(C_GT(cell,subthread_three)/6.+C_GT(cell,subthread_five)/6.);

			SS_four_four=3.*(C_GT(cell,subthread_four)/6.+C_GT(cell,subthread_four)/6.);
			SS_four_five=3.*(C_GT(cell,subthread_four)/6.+C_GT(cell,subthread_five)/6.);

			SS_five_five=3.*(C_GT(cell,subthread_five)/6.+C_GT(cell,subthread_five)/6.);

			Sagg_one_one=1.-exp(-pow(v_crit_a_one_one,2.)/(2.*SS_one_one));
			Sagg_one_two=1.-exp(-pow(v_crit_a_one_two,2.)/(2.*SS_one_two));
			Sagg_one_three=1.-exp(-pow(v_crit_a_one_three,2.)/(2.*SS_one_three));
			Sagg_one_four=1.-exp(-pow(v_crit_a_one_four,2.)/(2.*SS_one_four));

			Sagg_two_two=1.-exp(-pow(v_crit_a_two_two,2.)/(2.*SS_two_two));
			Sagg_two_three=1.-exp(-pow(v_crit_a_two_three,2.)/(2.*SS_two_three));

			Sbrk_one_two=exp(-pow(v_crit_b_one_two,2.)/(2.*SS_one_two));
			Sbrk_one_three=exp(-pow(v_crit_b_one_three,2.)/(2.*SS_one_three));
			Sbrk_one_four=exp(-pow(v_crit_b_one_four,2.)/(2.*SS_one_four));
			Sbrk_one_five=exp(-pow(v_crit_b_one_five,2.)/(2.*SS_one_five));

			Sbrk_two_two=exp(-pow(v_crit_b_two_two,2.)/(2.*SS_two_two));
			Sbrk_two_three=exp(-pow(v_crit_b_two_three,2.)/(2.*SS_two_three));
			Sbrk_two_four=exp(-pow(v_crit_b_two_four,2.)/(2.*SS_two_four));
			Sbrk_two_five=exp(-pow(v_crit_b_two_five,2.)/(2.*SS_two_five));

			Sbrk_three_three=exp(-pow(v_crit_b_three_three,2.)/(2.*SS_three_three));
			Sbrk_three_four=exp(-pow(v_crit_b_three_four,2.)/(2.*SS_three_four));
			Sbrk_three_five=exp(-pow(v_crit_b_three_five,2.)/(2.*SS_three_five));

			Sbrk_four_four=exp(-pow(v_crit_b_four_four,2.)/(2.*SS_four_four));
			Sbrk_four_five=exp(-pow(v_crit_b_four_five,2.)/(2.*SS_four_five));

			Sbrk_five_five=exp(-pow(v_crit_b_five_five,2.)/(2.*SS_five_five));

			v_crit_a_one_five=0.013426;

			v_crit_a_two_four=0.015348;
			v_crit_a_two_five=0.007322;

			v_crit_a_three_three=0.012524;
			v_crit_a_three_four=v_crit_a_high;
			v_crit_a_three_five=v_crit_a_high;

			v_crit_a_four_four=v_crit_a_high;
			v_crit_a_four_five=v_crit_a_high;

			v_crit_a_five_five=v_crit_a_high;

			vmax_one_one=sqrt(6.*SS_one_one);
			vmax_one_two=sqrt(6.*SS_one_two);
			vmax_one_three=sqrt(6.*SS_one_three);
			vmax_one_four=sqrt(6.*SS_one_four);
			vmax_one_five=sqrt(6.*SS_one_five);

			vmax_two_two=sqrt(6.*SS_two_two);
			vmax_two_three=sqrt(6.*SS_two_three);
			vmax_two_four=sqrt(6.*SS_two_four);
			vmax_two_five=sqrt(6.*SS_two_five);

			vmax_three_three=sqrt(6.*SS_three_three);
			vmax_three_four=sqrt(6.*SS_three_four);
			vmax_three_five=sqrt(6.*SS_three_five);

			vmax_four_four=sqrt(6.*SS_four_four);
			vmax_four_five=sqrt(6.*SS_four_five);

			vmax_five_five=sqrt(6.*SS_five_five);

			dv_one_one=(vmax_one_one-v_crit_a_one_one)/nrect;
			dv_one_two=(vmax_one_two-v_crit_a_one_two)/nrect;
			dv_one_three=(vmax_one_three-v_crit_a_one_three)/nrect;
			dv_one_four=(vmax_one_four-v_crit_a_one_four)/nrect;
			dv_one_five=(vmax_one_five-v_crit_a_one_five)/nrect;

			dv_two_two=(vmax_two_two-v_crit_a_two_two)/nrect;
			dv_two_three=(vmax_two_three-v_crit_a_two_three)/nrect;
			dv_two_four=(vmax_two_four-v_crit_a_two_four)/nrect;
			dv_two_five=(vmax_two_five-v_crit_a_two_five)/nrect;

			dv_three_three=(vmax_three_three-v_crit_a_three_three)/nrect;
			dv_three_four=(vmax_three_four-v_crit_a_three_four)/nrect;
			dv_three_five=(vmax_three_five-v_crit_a_three_five)/nrect;

			dv_four_four=(vmax_four_four-v_crit_a_four_four)/nrect;
			dv_four_five=(vmax_four_five-v_crit_a_four_five)/nrect;

			dv_five_five=(vmax_five_five-v_crit_a_five_five)/nrect;

			vn_one_one=v_crit_a_one_one;
			vn_one_two=v_crit_a_one_two;
			vn_one_three=v_crit_a_one_three;
			vn_one_four=v_crit_a_one_four;
			vn_one_five=v_crit_a_one_five;

			vn_two_two=v_crit_a_two_two;
			vn_two_three=v_crit_a_two_three;
			vn_two_four=v_crit_a_two_four;
			vn_two_five=v_crit_a_two_five;

			vn_three_three=v_crit_a_three_three;
			vn_three_four=v_crit_a_three_four;
			vn_three_five=v_crit_a_three_five;

			vn_four_four=v_crit_a_four_four;
			vn_four_five=v_crit_a_four_five;

			vn_five_five=v_crit_a_five_five;

			corsum_one_one=sqrt(1.-pow(v_crit_a_one_one/vn_one_one,2.))*vn_one_one*exp(-pow(vn_one_one,2.)/(2.*SS_one_one));
			corsum_one_two=sqrt(1.-pow(v_crit_a_one_two/vn_one_two,2.))*vn_one_two*exp(-pow(vn_one_two,2.)/(2.*SS_one_two));
			corsum_one_three=sqrt(1.-pow(v_crit_a_one_three/vn_one_three,2.))*vn_one_three*exp(-pow(vn_one_three,2.)/(2.*SS_one_three));
			corsum_one_four=sqrt(1.-pow(v_crit_a_one_four/vn_one_four,2.))*vn_one_four*exp(-pow(vn_one_four,2.)/(2.*SS_one_four));
			corsum_one_five=sqrt(1.-pow(v_crit_a_one_five/vn_one_five,2.))*vn_one_five*exp(-pow(vn_one_five,2.)/(2.*SS_one_five));

			corsum_two_two=sqrt(1.-pow(v_crit_a_two_two/vn_two_two,2.))*vn_two_two*exp(-pow(vn_two_two,2.)/(2.*SS_two_two));
			corsum_two_three=sqrt(1.-pow(v_crit_a_two_three/vn_two_three,2.))*vn_two_three*exp(-pow(vn_two_three,2.)/(2.*SS_two_three));
			corsum_two_four=sqrt(1.-pow(v_crit_a_two_four/vn_two_four,2.))*vn_two_four*exp(-pow(vn_two_four,2.)/(2.*SS_two_four));
			corsum_two_five=sqrt(1.-pow(v_crit_a_two_five/vn_two_five,2.))*vn_two_five*exp(-pow(vn_two_five,2.)/(2.*SS_two_five));

			corsum_three_three=sqrt(1.-pow(v_crit_a_three_three/vn_three_three,2.))*vn_three_three*exp(-pow(vn_three_three,2.)/(2.*SS_three_three));
			corsum_three_four=sqrt(1.-pow(v_crit_a_three_four/vn_three_four,2.))*vn_three_four*exp(-pow(vn_three_four,2.)/(2.*SS_three_four));
			corsum_three_five=sqrt(1.-pow(v_crit_a_three_five/vn_three_five,2.))*vn_three_five*exp(-pow(vn_three_five,2.)/(2.*SS_three_five));

			corsum_four_four=sqrt(1.-pow(v_crit_a_four_four/vn_four_four,2.))*vn_four_four*exp(-pow(vn_four_four,2.)/(2.*SS_four_four));
			corsum_four_five=sqrt(1.-pow(v_crit_a_four_five/vn_four_five,2.))*vn_four_five*exp(-pow(vn_four_five,2.)/(2.*SS_four_five));

			corsum_five_five=sqrt(1.-pow(v_crit_a_five_five/vn_five_five,2.))*vn_five_five*exp(-pow(vn_five_five,2.)/(2.*SS_five_five));

			vn_one_one=vmax_one_one;
			vn_one_two=vmax_one_two;
			vn_one_three=vmax_one_three;
			vn_one_four=vmax_one_four;
			vn_one_five=vmax_one_five;

			vn_two_two=vmax_two_two;
			vn_two_three=vmax_two_three;
			vn_two_four=vmax_two_four;
			vn_two_five=vmax_two_five;

			vn_three_three=vmax_three_three;
			vn_three_four=vmax_three_four;
			vn_three_five=vmax_three_five;

			vn_four_four=vmax_four_four;
			vn_four_five=vmax_four_five;

			vn_five_five=vmax_five_five;

			corsum_one_one=corsum_one_one+sqrt(1.-pow(v_crit_a_one_one/vn_one_one,2.))*vn_one_one*exp(-pow(vn_one_one,2.)/(2.*SS_one_one));
			corsum_one_two=corsum_one_two+sqrt(1.-pow(v_crit_a_one_two/vn_one_two,2.))*vn_one_two*exp(-pow(vn_one_two,2.)/(2.*SS_one_two));
			corsum_one_three=corsum_one_three+sqrt(1.-pow(v_crit_a_one_three/vn_one_three,2.))*vn_one_three*exp(-pow(vn_one_three,2.)/(2.*SS_one_three));
			corsum_one_four=corsum_one_four+sqrt(1.-pow(v_crit_a_one_four/vn_one_four,2.))*vn_one_four*exp(-pow(vn_one_four,2.)/(2.*SS_one_four));
			corsum_one_five=corsum_one_five+sqrt(1.-pow(v_crit_a_one_five/vn_one_five,2.))*vn_one_five*exp(-pow(vn_one_five,2.)/(2.*SS_one_five));

			corsum_two_two=corsum_two_two+sqrt(1.-pow(v_crit_a_two_two/vn_two_two,2.))*vn_two_two*exp(-pow(vn_two_two,2.)/(2.*SS_two_two));
			corsum_two_three=corsum_two_three+sqrt(1.-pow(v_crit_a_two_three/vn_two_three,2.))*vn_two_three*exp(-pow(vn_two_three,2.)/(2.*SS_two_three));
			corsum_two_four=corsum_two_four+sqrt(1.-pow(v_crit_a_two_four/vn_two_four,2.))*vn_two_four*exp(-pow(vn_two_four,2.)/(2.*SS_two_four));
			corsum_two_five=corsum_two_five+sqrt(1.-pow(v_crit_a_two_five/vn_two_five,2.))*vn_two_five*exp(-pow(vn_two_five,2.)/(2.*SS_two_five));

			corsum_three_three=corsum_three_three+sqrt(1.-pow(v_crit_a_three_three/vn_three_three,2.))*vn_three_three*exp(-pow(vn_three_three,2.)/(2.*SS_three_three));
			corsum_three_four=corsum_three_four+sqrt(1.-pow(v_crit_a_three_four/vn_three_four,2.))*vn_three_four*exp(-pow(vn_three_four,2.)/(2.*SS_three_four));
			corsum_three_five=corsum_three_five+sqrt(1.-pow(v_crit_a_three_five/vn_three_five,2.))*vn_three_five*exp(-pow(vn_three_five,2.)/(2.*SS_three_five));

			corsum_four_four=corsum_four_four+sqrt(1.-pow(v_crit_a_four_four/vn_four_four,2.))*vn_four_four*exp(-pow(vn_four_four,2.)/(2.*SS_four_four));
			corsum_four_five=corsum_four_five+sqrt(1.-pow(v_crit_a_four_five/vn_four_five,2.))*vn_four_five*exp(-pow(vn_four_five,2.)/(2.*SS_four_five));

			corsum_five_five=corsum_five_five+sqrt(1.-pow(v_crit_a_five_five/vn_five_five,2.))*vn_five_five*exp(-pow(vn_five_five,2.)/(2.*SS_five_five));

			corsum_one_one=corsum_one_one/2.;
			corsum_one_two=corsum_one_two/2.;
			corsum_one_three=corsum_one_three/2.;
			corsum_one_four=corsum_one_four/2.;
			corsum_one_five=corsum_one_five/2.;

			corsum_two_two=corsum_two_two/2.;
			corsum_two_three=corsum_two_three/2.;
			corsum_two_four=corsum_two_four/2.;
			corsum_two_five=corsum_two_five/2.;

			corsum_three_three=corsum_three_three/2.;
			corsum_three_four=corsum_three_four/2.;
			corsum_three_five=corsum_three_five/2.;

			corsum_four_four=corsum_four_four/2.;
			corsum_four_five=corsum_four_five/2.;

			corsum_five_five=corsum_five_five/2.;

			for(i=1.;i<=nrect-1.;i++)
				{
				vn_one_one=v_crit_a_one_one+dv_one_one*i;
				vn_one_two=v_crit_a_one_two+dv_one_two*i;
				vn_one_three=v_crit_a_one_three+dv_one_three*i;
				vn_one_four=v_crit_a_one_four+dv_one_four*i;
				vn_one_five=v_crit_a_one_five+dv_one_five*i;

				vn_two_two=v_crit_a_two_two+dv_two_two*i;
				vn_two_three=v_crit_a_two_three+dv_two_three*i;
				vn_two_four=v_crit_a_two_four+dv_two_four*i;
				vn_two_five=v_crit_a_two_five+dv_two_five*i;

				vn_three_three=v_crit_a_three_three+dv_three_three*i;
				vn_three_four=v_crit_a_three_four+dv_three_four*i;
				vn_three_five=v_crit_a_three_five+dv_three_five*i;

				vn_four_four=v_crit_a_four_four+dv_four_four*i;
				vn_four_five=v_crit_a_four_five+dv_four_five*i;

				vn_five_five=v_crit_a_five_five+dv_five_five*i;

				corsum_one_one=corsum_one_one+sqrt(1.-pow(v_crit_a_one_one/vn_one_one,2.))*vn_one_one*exp(-pow(vn_one_one,2.)/(2.*SS_one_one));
				corsum_one_two=corsum_one_two+sqrt(1.-pow(v_crit_a_one_two/vn_one_two,2.))*vn_one_two*exp(-pow(vn_one_two,2.)/(2.*SS_one_two));
				corsum_one_three=corsum_one_three+sqrt(1.-pow(v_crit_a_one_three/vn_one_three,2.))*vn_one_three*exp(-pow(vn_one_three,2.)/(2.*SS_one_three));
				corsum_one_four=corsum_one_four+sqrt(1.-pow(v_crit_a_one_four/vn_one_four,2.))*vn_one_four*exp(-pow(vn_one_four,2.)/(2.*SS_one_four));
				corsum_one_five=corsum_one_five+sqrt(1.-pow(v_crit_a_one_five/vn_one_five,2.))*vn_one_five*exp(-pow(vn_one_five,2.)/(2.*SS_one_five));

				corsum_two_two=corsum_two_two+sqrt(1.-pow(v_crit_a_two_two/vn_two_two,2.))*vn_two_two*exp(-pow(vn_two_two,2.)/(2.*SS_two_two));
				corsum_two_three=corsum_two_three+sqrt(1.-pow(v_crit_a_two_three/vn_two_three,2.))*vn_two_three*exp(-pow(vn_two_three,2.)/(2.*SS_two_three));
				corsum_two_four=corsum_two_four+sqrt(1.-pow(v_crit_a_two_four/vn_two_four,2.))*vn_two_four*exp(-pow(vn_two_four,2.)/(2.*SS_two_four));
				corsum_two_five=corsum_two_five+sqrt(1.-pow(v_crit_a_two_five/vn_two_five,2.))*vn_two_five*exp(-pow(vn_two_five,2.)/(2.*SS_two_five));

				corsum_three_three=corsum_three_three+sqrt(1.-pow(v_crit_a_three_three/vn_three_three,2.))*vn_three_three*exp(-pow(vn_three_three,2.)/(2.*SS_three_three));
				corsum_three_four=corsum_three_four+sqrt(1.-pow(v_crit_a_three_four/vn_three_four,2.))*vn_three_four*exp(-pow(vn_three_four,2.)/(2.*SS_three_four));
				corsum_three_five=corsum_three_five+sqrt(1.-pow(v_crit_a_three_five/vn_three_five,2.))*vn_three_five*exp(-pow(vn_three_five,2.)/(2.*SS_three_five));

				corsum_four_four=corsum_four_four+sqrt(1.-pow(v_crit_a_four_four/vn_four_four,2.))*vn_four_four*exp(-pow(vn_four_four,2.)/(2.*SS_four_four));
				corsum_four_five=corsum_four_five+sqrt(1.-pow(v_crit_a_four_five/vn_four_five,2.))*vn_four_five*exp(-pow(vn_four_five,2.)/(2.*SS_four_five));

				corsum_five_five=corsum_five_five+sqrt(1.-pow(v_crit_a_five_five/vn_five_five,2.))*vn_five_five*exp(-pow(vn_five_five,2.)/(2.*SS_five_five));				
				}
		
			corsum_one_one=corinp*dv_one_one*corsum_one_one/(SS_one_one*(exp(-pow(v_crit_a_one_one,2.)/(2.*SS_one_one))-exp(-pow(vmax_one_one,2.)/(2.*SS_one_one))));
			corsum_one_two=corinp*dv_one_two*corsum_one_two/(SS_one_two*(exp(-pow(v_crit_a_one_two,2.)/(2.*SS_one_two))-exp(-pow(vmax_one_two,2.)/(2.*SS_one_two))));
			corsum_one_three=corinp*dv_one_three*corsum_one_three/(SS_one_three*(exp(-pow(v_crit_a_one_three,2.)/(2.*SS_one_three))-exp(-pow(vmax_one_three,2.)/(2.*SS_one_three))));
			corsum_one_four=corinp*dv_one_four*corsum_one_four/(SS_one_four*(exp(-pow(v_crit_a_one_four,2.)/(2.*SS_one_four))-exp(-pow(vmax_one_four,2.)/(2.*SS_one_four))));
			corsum_one_five=corinp*dv_one_five*corsum_one_five/(SS_one_five*(exp(-pow(v_crit_a_one_five,2.)/(2.*SS_one_five))-exp(-pow(vmax_one_five,2.)/(2.*SS_one_five))));

			corsum_two_two=corinp*dv_two_two*corsum_two_two/(SS_two_two*(exp(-pow(v_crit_a_two_two,2.)/(2.*SS_two_two))-exp(-pow(vmax_two_two,2.)/(2.*SS_two_two))));
			corsum_two_three=corinp*dv_two_three*corsum_two_three/(SS_two_three*(exp(-pow(v_crit_a_two_three,2.)/(2.*SS_two_three))-exp(-pow(vmax_two_three,2.)/(2.*SS_two_three))));
			corsum_two_four=corinp*dv_two_four*corsum_two_four/(SS_two_four*(exp(-pow(v_crit_a_two_four,2.)/(2.*SS_two_four))-exp(-pow(vmax_two_four,2.)/(2.*SS_two_four))));
			corsum_two_five=corinp*dv_two_five*corsum_two_five/(SS_two_five*(exp(-pow(v_crit_a_two_five,2.)/(2.*SS_two_five))-exp(-pow(vmax_two_five,2.)/(2.*SS_two_five))));

			corsum_three_three=corinp*dv_three_three*corsum_three_three/(SS_three_three*(exp(-pow(v_crit_a_three_three,2.)/(2.*SS_three_three))-exp(-pow(vmax_three_three,2.)/(2.*SS_three_three))));
			corsum_three_four=corinp*dv_three_four*corsum_three_four/(SS_three_four*(exp(-pow(v_crit_a_three_four,2.)/(2.*SS_three_four))-exp(-pow(vmax_three_four,2.)/(2.*SS_three_four))));
			corsum_three_five=corinp*dv_three_five*corsum_three_five/(SS_three_five*(exp(-pow(v_crit_a_three_five,2.)/(2.*SS_three_five))-exp(-pow(vmax_three_five,2.)/(2.*SS_three_five))));

			corsum_four_four=corinp*dv_four_four*corsum_four_four/(SS_four_four*(exp(-pow(v_crit_a_four_four,2.)/(2.*SS_four_four))-exp(-pow(vmax_four_four,2.)/(2.*SS_four_four))));
			corsum_four_five=corinp*dv_four_five*corsum_four_five/(SS_four_five*(exp(-pow(v_crit_a_four_five,2.)/(2.*SS_four_five))-exp(-pow(vmax_four_five,2.)/(2.*SS_four_five))));

			corsum_five_five=corinp*dv_five_five*corsum_five_five/(SS_five_five*(exp(-pow(v_crit_a_five_five,2.)/(2.*SS_five_five))-exp(-pow(vmax_five_five,2.)/(2.*SS_five_five))));

			e_one_one=corsum_one_one;
			e_one_two=corsum_one_two;
			e_one_three=corsum_one_three;
			e_one_four=corsum_one_four;
			e_one_five=corsum_one_five;

			e_two_two=corsum_two_two;
			e_two_three=corsum_two_three;
			e_two_four=corsum_two_four;
			e_two_five=corsum_two_five;

			e_three_three=corsum_three_three;
			e_three_four=corsum_three_four;
			e_three_five=corsum_three_five;

			e_four_four=corsum_four_four;
			e_four_five=corsum_four_five;

			e_five_five=corsum_five_five;

			n_one=C_VOF(cell,subthread_one)*rhop/m_one;
			n_two=C_VOF(cell,subthread_two)*rhop/m_two;
			n_three=C_VOF(cell,subthread_three)*rhop/m_three;
			n_four=C_VOF(cell,subthread_four)*rhop/m_four;
			n_five=C_VOF(cell,subthread_five)*rhop/m_five;

			P_one_k=rhop*C_VOF(cell,subthread_one)*theta_one/m_one;
			P_two_k=rhop*C_VOF(cell,subthread_two)*theta_two/m_two;
			P_three_k=rhop*C_VOF(cell,subthread_three)*theta_three/m_three;
			P_four_k=rhop*C_VOF(cell,subthread_four)*theta_four/m_four;
			P_five_k=rhop*C_VOF(cell,subthread_five)*theta_five/m_five;


			A_one_one=m_one/theta_one;
			A_one_two=(m_one*theta_two+m_two*theta_one)/(2.*theta_one*theta_two);
			A_one_three=(m_one*theta_three+m_three*theta_one)/(2.*theta_one*theta_three);
			A_one_four=(m_one*theta_four+m_four*theta_one)/(2.*theta_one*theta_four);
			A_one_five=(m_one*theta_five+m_five*theta_one)/(2.*theta_one*theta_five);

			A_two_two=m_two/theta_two;
			A_two_three=(m_two*theta_three+m_three*theta_two)/(2.*theta_two*theta_three);
			A_two_four=(m_two*theta_four+m_four*theta_two)/(2.*theta_two*theta_four);
			A_two_five=(m_two*theta_five+m_five*theta_two)/(2.*theta_two*theta_five);

			A_three_three=m_three/theta_three;
			A_three_four=(m_three*theta_four+m_four*theta_three)/(2.*theta_three*theta_four);
			A_three_five=(m_three*theta_five+m_five*theta_three)/(2.*theta_three*theta_five);

			A_four_four=m_four/theta_four;
			A_four_five=(m_four*theta_five+m_five*theta_four)/(2.*theta_four*theta_five);

			A_five_five=m_five/theta_five;


			B_one_two=(m_one*m_two*(theta_two-theta_one))/(2.*(m_one+m_two)*theta_one*theta_two);
			B_one_three=(m_one*m_three*(theta_three-theta_one))/(2.*(m_one+m_three)*theta_one*theta_three);
			B_one_four=(m_one*m_four*(theta_four-theta_one))/(2.*(m_one+m_four)*theta_one*theta_four);
			B_one_five=(m_one*m_five*(theta_five-theta_one))/(2.*(m_one+m_five)*theta_one*theta_five);
			
			B_two_one=(m_two*m_one*(theta_one-theta_two))/(2.*(m_two+m_one)*theta_two*theta_one);
			B_two_three=(m_two*m_three*(theta_three-theta_two))/(2.*(m_two+m_three)*theta_two*theta_three);
			B_two_four=(m_two*m_four*(theta_four-theta_two))/(2.*(m_two+m_four)*theta_two*theta_four);
			B_two_five=(m_two*m_five*(theta_five-theta_two))/(2.*(m_two+m_five)*theta_two*theta_five);

			B_three_one=(m_three*m_one*(theta_one-theta_three))/(2.*(m_three+m_one)*theta_three*theta_one);
			B_three_two=(m_three*m_two*(theta_two-theta_three))/(2.*(m_three+m_two)*theta_three*theta_two);
			B_three_four=(m_three*m_four*(theta_four-theta_three))/(2.*(m_three+m_four)*theta_three*theta_four);
			B_three_five=(m_three*m_five*(theta_five-theta_three))/(2.*(m_three+m_five)*theta_three*theta_five);

			B_four_one=(m_four*m_one*(theta_one-theta_four))/(2.*(m_four+m_one)*theta_four*theta_one);
			B_four_two=(m_four*m_two*(theta_two-theta_four))/(2.*(m_four+m_two)*theta_four*theta_two);
			B_four_three=(m_four*m_three*(theta_three-theta_four))/(2.*(m_four+m_three)*theta_four*theta_three);			
			B_four_five=(m_four*m_five*(theta_five-theta_four))/(2.*(m_four+m_five)*theta_four*theta_five);

			B_five_one=(m_five*m_one*(theta_one-theta_five))/(2.*(m_five+m_one)*theta_five*theta_one);
			B_five_two=(m_five*m_two*(theta_two-theta_five))/(2.*(m_five+m_two)*theta_five*theta_two);
			B_five_three=(m_five*m_three*(theta_three-theta_five))/(2.*(m_five+m_three)*theta_five*theta_three);			
			B_five_four=(m_five*m_four*(theta_four-theta_five))/(2.*(m_five+m_four)*theta_five*theta_four);


			D_one_one=m_one/(4.*theta_one);
			D_one_two=(m_one*m_two*(m_two*theta_two+m_one*theta_one))/(2.*(m_one+m_two)*(m_one+m_two)*theta_one*theta_two);
			D_one_three=(m_one*m_three*(m_three*theta_three+m_one*theta_one))/(2.*(m_one+m_three)*(m_one+m_three)*theta_one*theta_three);
			D_one_four=(m_one*m_four*(m_four*theta_four+m_one*theta_one))/(2.*(m_one+m_four)*(m_one+m_four)*theta_one*theta_four);
			D_one_five=(m_one*m_five*(m_five*theta_five+m_one*theta_one))/(2.*(m_one+m_five)*(m_one+m_five)*theta_one*theta_five);

			D_two_two=m_two/(4.*theta_two);
			D_two_three=(m_two*m_three*(m_three*theta_three+m_two*theta_two))/(2.*(m_two+m_three)*(m_two+m_three)*theta_two*theta_three);
			D_two_four=(m_two*m_four*(m_four*theta_four+m_two*theta_two))/(2.*(m_two+m_four)*(m_two+m_four)*theta_two*theta_four);
			D_two_five=(m_two*m_five*(m_five*theta_five+m_two*theta_two))/(2.*(m_two+m_five)*(m_two+m_five)*theta_two*theta_five);

			D_three_three=m_three/(4.*theta_three);
			D_three_four=(m_three*m_four*(m_four*theta_four+m_three*theta_three))/(2.*(m_three+m_four)*(m_three+m_four)*theta_three*theta_four);
			D_three_five=(m_three*m_five*(m_five*theta_five+m_three*theta_three))/(2.*(m_three+m_five)*(m_three+m_five)*theta_three*theta_five);

			D_four_four=m_four/(4.*theta_four);
			D_four_five=(m_four*m_five*(m_five*theta_five+m_four*theta_four))/(2.*(m_four+m_five)*(m_four+m_five)*theta_four*theta_five);

			D_five_five=m_five/(4.*theta_five);


			R_zero_one_one=1./sqrt(pow(A_one_one,3.)*pow(D_one_one,5.));
			R_zero_one_two=1./sqrt(pow(A_one_two,3.)*pow(D_one_two,5.))+15.*pow(B_one_two,2.)/(2.*sqrt(pow(A_one_two,5.)*pow(D_one_two,7.)))+175.*pow(B_one_two,4.)/(8.*sqrt(pow(A_one_two,7.)*pow(D_one_two,9.)));
			R_zero_one_three=1./sqrt(pow(A_one_three,3.)*pow(D_one_three,5.))+15.*pow(B_one_three,2.)/(2.*sqrt(pow(A_one_three,5.)*pow(D_one_three,7.)))+175.*pow(B_one_three,4.)/(8.*sqrt(pow(A_one_three,7.)*pow(D_one_three,9.)));
			R_zero_one_four=1./sqrt(pow(A_one_four,3.)*pow(D_one_four,5.))+15.*pow(B_one_four,2.)/(2.*sqrt(pow(A_one_four,5.)*pow(D_one_four,7.)))+175.*pow(B_one_four,4.)/(8.*sqrt(pow(A_one_four,7.)*pow(D_one_four,9.)));
			R_zero_one_five=1./sqrt(pow(A_one_five,3.)*pow(D_one_five,5.))+15.*pow(B_one_five,2.)/(2.*sqrt(pow(A_one_five,5.)*pow(D_one_five,7.)))+175.*pow(B_one_five,4.)/(8.*sqrt(pow(A_one_five,7.)*pow(D_one_five,9.)));

			R_zero_two_two=1./sqrt(pow(A_two_two,3.)*pow(D_two_two,5.));
			R_zero_two_three=1./sqrt(pow(A_two_three,3.)*pow(D_two_three,5.))+15.*pow(B_two_three,2.)/(2.*sqrt(pow(A_two_three,5.)*pow(D_two_three,7.)))+175.*pow(B_two_three,4.)/(8.*sqrt(pow(A_two_three,7.)*pow(D_two_three,9.)));
			R_zero_two_four=1./sqrt(pow(A_two_four,3.)*pow(D_two_four,5.))+15.*pow(B_two_four,2.)/(2.*sqrt(pow(A_two_four,5.)*pow(D_two_four,7.)))+175.*pow(B_two_four,4.)/(8.*sqrt(pow(A_two_four,7.)*pow(D_two_four,9.)));
			R_zero_two_five=1./sqrt(pow(A_two_five,3.)*pow(D_two_five,5.))+15.*pow(B_two_five,2.)/(2.*sqrt(pow(A_two_five,5.)*pow(D_two_five,7.)))+175.*pow(B_two_five,4.)/(8.*sqrt(pow(A_two_five,7.)*pow(D_two_five,9.)));

			R_zero_three_three=1./sqrt(pow(A_three_three,3.)*pow(D_three_three,5.));
			R_zero_three_four=1./sqrt(pow(A_three_four,3.)*pow(D_three_four,5.))+15.*pow(B_three_four,2.)/(2.*sqrt(pow(A_three_four,5.)*pow(D_three_four,7.)))+175.*pow(B_three_four,4.)/(8.*sqrt(pow(A_three_four,7.)*pow(D_three_four,9.)));
			R_zero_three_five=1./sqrt(pow(A_three_five,3.)*pow(D_three_five,5.))+15.*pow(B_three_five,2.)/(2.*sqrt(pow(A_three_five,5.)*pow(D_three_five,7.)))+175.*pow(B_three_five,4.)/(8.*sqrt(pow(A_three_five,7.)*pow(D_three_five,9.)));

			R_zero_four_four=1./sqrt(pow(A_four_four,3.)*pow(D_four_four,5.));
			R_zero_four_five=1./sqrt(pow(A_four_five,3.)*pow(D_four_five,5.))+15.*pow(B_four_five,2.)/(2.*sqrt(pow(A_four_five,5.)*pow(D_four_five,7.)))+175.*pow(B_four_five,4.)/(8.*sqrt(pow(A_four_five,7.)*pow(D_four_five,9.)));

			R_zero_five_five=1./sqrt(pow(A_five_five,3.)*pow(D_five_five,5.));


			R_one_one_one=1./(pow(A_one_one,1.5)*pow(D_one_one,3.));
			R_one_one_two=1./(pow(A_one_two,1.5)*pow(D_one_two,3.))+9.*pow(B_one_two,2.)/(pow(A_one_two,2.5)*pow(D_one_two,4.))+30.*pow(B_one_two,4.)/(2.*pow(A_one_two,3.5)*pow(D_one_two,5.));
			R_one_one_three=1./(pow(A_one_three,1.5)*pow(D_one_three,3.))+9.*pow(B_one_three,2.)/(pow(A_one_three,2.5)*pow(D_one_three,4.))+30.*pow(B_one_three,4.)/(2.*pow(A_one_three,3.5)*pow(D_one_three,5.));
			R_one_one_four=1./(pow(A_one_four,1.5)*pow(D_one_four,3.))+9.*pow(B_one_four,2.)/(pow(A_one_four,2.5)*pow(D_one_four,4.))+30.*pow(B_one_four,4.)/(2.*pow(A_one_four,3.5)*pow(D_one_four,5.));
			R_one_one_five=1./(pow(A_one_five,1.5)*pow(D_one_five,3.))+9.*pow(B_one_five,2.)/(pow(A_one_five,2.5)*pow(D_one_five,4.))+30.*pow(B_one_five,4.)/(2.*pow(A_one_five,3.5)*pow(D_one_five,5.));

			R_one_two_two=1./(pow(A_two_two,1.5)*pow(D_two_two,3.));
			R_one_two_three=1./(pow(A_two_three,1.5)*pow(D_two_three,3.))+9.*pow(B_two_three,2.)/(pow(A_two_three,2.5)*pow(D_two_three,4.))+30.*pow(B_two_three,4.)/(2.*pow(A_two_three,3.5)*pow(D_two_three,5.));
			R_one_two_four=1./(pow(A_two_four,1.5)*pow(D_two_four,3.))+9.*pow(B_two_four,2.)/(pow(A_two_four,2.5)*pow(D_two_four,4.))+30.*pow(B_two_four,4.)/(2.*pow(A_two_four,3.5)*pow(D_two_four,5.));
			R_one_two_five=1./(pow(A_two_five,1.5)*pow(D_two_five,3.))+9.*pow(B_two_five,2.)/(pow(A_two_five,2.5)*pow(D_two_five,4.))+30.*pow(B_two_five,4.)/(2.*pow(A_two_five,3.5)*pow(D_two_five,5.));

			R_one_three_three=1./(pow(A_three_three,1.5)*pow(D_three_three,3.));
			R_one_three_four=1./(pow(A_three_four,1.5)*pow(D_three_four,3.))+9.*pow(B_three_four,2.)/(pow(A_three_four,2.5)*pow(D_three_four,4.))+30.*pow(B_three_four,4.)/(2.*pow(A_three_four,3.5)*pow(D_three_four,5.));
			R_one_three_five=1./(pow(A_three_five,1.5)*pow(D_three_five,3.))+9.*pow(B_three_five,2.)/(pow(A_three_five,2.5)*pow(D_three_five,4.))+30.*pow(B_three_five,4.)/(2.*pow(A_three_five,3.5)*pow(D_three_five,5.));

			R_one_four_four=1./(pow(A_four_four,1.5)*pow(D_four_four,3.));
			R_one_four_five=1./(pow(A_four_five,1.5)*pow(D_four_five,3.))+9.*pow(B_four_five,2.)/(pow(A_four_five,2.5)*pow(D_four_five,4.))+30.*pow(B_four_five,4.)/(2.*pow(A_four_five,3.5)*pow(D_four_five,5.));

			R_one_five_five=1./(pow(A_five_five,1.5)*pow(D_five_five,3.));


			R_two_one_one=1./(2.*pow(A_one_one,1.5)*pow(D_one_one,2.));
			R_two_one_two=1./(2.*pow(A_one_two,1.5)*pow(D_one_two,2.))+3.*pow(B_one_two,2.)/(pow(A_one_two,2.5)*pow(D_one_two,3.))+15.*pow(B_one_two,4.)/(2.*pow(A_one_two,3.5)*pow(D_one_two,4.));
			R_two_one_three=1./(2.*pow(A_one_three,1.5)*pow(D_one_three,2.))+3.*pow(B_one_three,2.)/(pow(A_one_three,2.5)*pow(D_one_three,3.))+15.*pow(B_one_three,4.)/(2.*pow(A_one_three,3.5)*pow(D_one_three,4.));
			R_two_one_four=1./(2.*pow(A_one_four,1.5)*pow(D_one_four,2.))+3.*pow(B_one_four,2.)/(pow(A_one_four,2.5)*pow(D_one_four,3.))+15.*pow(B_one_four,4.)/(2.*pow(A_one_four,3.5)*pow(D_one_four,4.));
			R_two_one_five=1./(2.*pow(A_one_five,1.5)*pow(D_one_five,2.))+3.*pow(B_one_five,2.)/(pow(A_one_five,2.5)*pow(D_one_five,3.))+15.*pow(B_one_five,4.)/(2.*pow(A_one_five,3.5)*pow(D_one_five,4.));

			R_two_two_two=1./(2.*pow(A_two_two,1.5)*pow(D_two_two,2.));
			R_two_two_three=1./(2.*pow(A_two_three,1.5)*pow(D_two_three,2.))+3.*pow(B_two_three,2.)/(pow(A_two_three,2.5)*pow(D_two_three,3.))+15.*pow(B_two_three,4.)/(2.*pow(A_two_three,3.5)*pow(D_two_three,4.));
			R_two_two_four=1./(2.*pow(A_two_four,1.5)*pow(D_two_four,2.))+3.*pow(B_two_four,2.)/(pow(A_two_four,2.5)*pow(D_two_four,3.))+15.*pow(B_two_four,4.)/(2.*pow(A_two_four,3.5)*pow(D_two_four,4.));
			R_two_two_five=1./(2.*pow(A_two_five,1.5)*pow(D_two_five,2.))+3.*pow(B_two_five,2.)/(pow(A_two_five,2.5)*pow(D_two_five,3.))+15.*pow(B_two_five,4.)/(2.*pow(A_two_five,3.5)*pow(D_two_five,4.));

			R_two_three_three=1./(2.*pow(A_three_three,1.5)*pow(D_three_three,2.));
			R_two_three_four=1./(2.*pow(A_three_four,1.5)*pow(D_three_four,2.))+3.*pow(B_three_four,2.)/(pow(A_three_four,2.5)*pow(D_three_four,3.))+15.*pow(B_three_four,4.)/(2.*pow(A_three_four,3.5)*pow(D_three_four,4.));
			R_two_three_five=1./(2.*pow(A_three_five,1.5)*pow(D_three_five,2.))+3.*pow(B_three_five,2.)/(pow(A_three_five,2.5)*pow(D_three_five,3.))+15.*pow(B_three_five,4.)/(2.*pow(A_three_five,3.5)*pow(D_three_five,4.));

			R_two_four_four=1./(2.*pow(A_four_four,1.5)*pow(D_four_four,2.));
			R_two_four_five=1./(2.*pow(A_four_five,1.5)*pow(D_four_five,2.))+3.*pow(B_four_five,2.)/(pow(A_four_five,2.5)*pow(D_four_five,3.))+15.*pow(B_four_five,4.)/(2.*pow(A_four_five,3.5)*pow(D_four_five,4.));

			R_two_five_five=1./(2.*pow(A_five_five,1.5)*pow(D_five_five,2.));

			/*
			R_three_one_one=1./(pow(A_one_one,1.5)*pow(D_one_one,3.5));
			R_three_one_two=1./(pow(A_one_two,1.5)*pow(D_one_two,3.5))+21.*pow(B_one_two,2.)/(2.*pow(A_one_two,2.5)*pow(D_one_two,4.5))+315.*pow(B_one_two,4.)/(8.*pow(A_one_two,3.5)*pow(D_one_two,5.5));
			R_three_one_three=1./(pow(A_one_three,1.5)*pow(D_one_three,3.5))+21.*pow(B_one_three,2.)/(2.*pow(A_one_three,2.5)*pow(D_one_three,4.5))+315.*pow(B_one_three,4.)/(8.*pow(A_one_three,3.5)*pow(D_one_three,5.5));
			R_three_one_four=1./(pow(A_one_four,1.5)*pow(D_one_four,3.5))+21.*pow(B_one_four,2.)/(2.*pow(A_one_four,2.5)*pow(D_one_four,4.5))+315.*pow(B_one_four,4.)/(8.*pow(A_one_four,3.5)*pow(D_one_four,5.5));
			R_three_one_five=1./(pow(A_one_five,1.5)*pow(D_one_five,3.5))+21.*pow(B_one_five,2.)/(2.*pow(A_one_five,2.5)*pow(D_one_five,4.5))+315.*pow(B_one_five,4.)/(8.*pow(A_one_five,3.5)*pow(D_one_five,5.5));

			R_three_two_two=1./(pow(A_two_two,1.5)*pow(D_two_two,3.5));
			R_three_two_three=1./(pow(A_two_three,1.5)*pow(D_two_three,3.5))+21.*pow(B_two_three,2.)/(2.*pow(A_two_three,2.5)*pow(D_two_three,4.5))+315.*pow(B_two_three,4.)/(8.*pow(A_two_three,3.5)*pow(D_two_three,5.5));
			R_three_two_four=1./(pow(A_two_four,1.5)*pow(D_two_four,3.5))+21.*pow(B_two_four,2.)/(2.*pow(A_two_four,2.5)*pow(D_two_four,4.5))+315.*pow(B_two_four,4.)/(8.*pow(A_two_four,3.5)*pow(D_two_four,5.5));
			R_three_two_five=1./(pow(A_two_five,1.5)*pow(D_two_five,3.5))+21.*pow(B_two_five,2.)/(2.*pow(A_two_five,2.5)*pow(D_two_five,4.5))+315.*pow(B_two_five,4.)/(8.*pow(A_two_five,3.5)*pow(D_two_five,5.5));

			R_three_three_three=1./(pow(A_three_three,1.5)*pow(D_three_three,3.5));
			R_three_three_four=1./(pow(A_three_four,1.5)*pow(D_three_four,3.5))+21.*pow(B_three_four,2.)/(2.*pow(A_three_four,2.5)*pow(D_three_four,4.5))+315.*pow(B_three_four,4.)/(8.*pow(A_three_four,3.5)*pow(D_three_four,5.5));
			R_three_three_five=1./(pow(A_three_five,1.5)*pow(D_three_five,3.5))+21.*pow(B_three_five,2.)/(2.*pow(A_three_five,2.5)*pow(D_three_five,4.5))+315.*pow(B_three_five,4.)/(8.*pow(A_three_five,3.5)*pow(D_three_five,5.5));

			R_three_four_four=1./(pow(A_four_four,1.5)*pow(D_four_four,3.5));
			R_three_four_five=1./(pow(A_four_five,1.5)*pow(D_four_five,3.5))+21.*pow(B_four_five,2.)/(2.*pow(A_four_five,2.5)*pow(D_four_five,4.5))+315.*pow(B_four_five,4.)/(8.*pow(A_four_five,3.5)*pow(D_four_five,5.5));

			R_three_five_five=1./(pow(A_five_five,1.5)*pow(D_five_five,3.5));


			R_four_one_one=3./(pow(A_one_one,2.5)*pow(D_one_one,3.5));
			R_four_one_two=3./(pow(A_one_two,2.5)*pow(D_one_two,3.5))+35.*pow(B_one_two,2.)/(2.*pow(A_one_two,3.5)*pow(D_one_two,4.5))+441.*pow(B_one_two,4.)/(8.*pow(A_one_two,4.5)*pow(D_one_two,5.5));
			R_four_one_three=3./(pow(A_one_three,2.5)*pow(D_one_three,3.5))+35.*pow(B_one_three,2.)/(2.*pow(A_one_three,3.5)*pow(D_one_three,4.5))+441.*pow(B_one_three,4.)/(8.*pow(A_one_three,4.5)*pow(D_one_three,5.5));
			R_four_one_four=3./(pow(A_one_four,2.5)*pow(D_one_four,3.5))+35.*pow(B_one_four,2.)/(2.*pow(A_one_four,3.5)*pow(D_one_four,4.5))+441.*pow(B_one_four,4.)/(8.*pow(A_one_four,4.5)*pow(D_one_four,5.5));
			R_four_one_five=3./(pow(A_one_five,2.5)*pow(D_one_five,3.5))+35.*pow(B_one_five,2.)/(2.*pow(A_one_five,3.5)*pow(D_one_five,4.5))+441.*pow(B_one_five,4.)/(8.*pow(A_one_five,4.5)*pow(D_one_five,5.5));

			R_four_two_two=3./(pow(A_two_two,2.5)*pow(D_two_two,3.5));
			R_four_two_three=3./(pow(A_two_three,2.5)*pow(D_two_three,3.5))+35.*pow(B_two_three,2.)/(2.*pow(A_two_three,3.5)*pow(D_two_three,4.5))+441.*pow(B_two_three,4.)/(8.*pow(A_two_three,4.5)*pow(D_two_three,5.5));
			R_four_two_four=3./(pow(A_two_four,2.5)*pow(D_two_four,3.5))+35.*pow(B_two_four,2.)/(2.*pow(A_two_four,3.5)*pow(D_two_four,4.5))+441.*pow(B_two_four,4.)/(8.*pow(A_two_four,4.5)*pow(D_two_four,5.5));
			R_four_two_five=3./(pow(A_two_five,2.5)*pow(D_two_five,3.5))+35.*pow(B_two_five,2.)/(2.*pow(A_two_five,3.5)*pow(D_two_five,4.5))+441.*pow(B_two_five,4.)/(8.*pow(A_two_five,4.5)*pow(D_two_five,5.5));

			R_four_three_three=3./(pow(A_three_three,2.5)*pow(D_three_three,3.5));
			R_four_three_four=3./(pow(A_three_four,2.5)*pow(D_three_four,3.5))+35.*pow(B_three_four,2.)/(2.*pow(A_three_four,3.5)*pow(D_three_four,4.5))+441.*pow(B_three_four,4.)/(8.*pow(A_three_four,4.5)*pow(D_three_four,5.5));
			R_four_three_five=3./(pow(A_three_five,2.5)*pow(D_three_five,3.5))+35.*pow(B_three_five,2.)/(2.*pow(A_three_five,3.5)*pow(D_three_five,4.5))+441.*pow(B_three_five,4.)/(8.*pow(A_three_five,4.5)*pow(D_three_five,5.5));

			R_four_four_four=3./(pow(A_four_four,2.5)*pow(D_four_four,3.5));
			R_four_four_five=3./(pow(A_four_five,2.5)*pow(D_four_five,3.5))+35.*pow(B_four_five,2.)/(2.*pow(A_four_five,3.5)*pow(D_four_five,4.5))+441.*pow(B_four_five,4.)/(8.*pow(A_four_five,4.5)*pow(D_four_five,5.5));

			R_four_five_five=3./(pow(A_five_five,2.5)*pow(D_five_five,3.5));
			*/

			R_five_one_one=1./(pow(A_one_one,2.5)*pow(D_one_one,3.));
			R_five_one_two=1./(pow(A_one_two,2.5)*pow(D_one_two,3.))+5.*pow(B_one_two,2.)/(pow(A_one_two,3.5)*pow(D_one_two,4.))+14.*pow(B_one_two,4.)/(pow(A_one_two,4.5)*pow(D_one_two,5.));
			R_five_one_three=1./(pow(A_one_three,2.5)*pow(D_one_three,3.))+5.*pow(B_one_three,2.)/(pow(A_one_three,3.5)*pow(D_one_three,4.))+14.*pow(B_one_three,4.)/(pow(A_one_three,4.5)*pow(D_one_three,5.));
			R_five_one_four=1./(pow(A_one_four,2.5)*pow(D_one_four,3.))+5.*pow(B_one_four,2.)/(pow(A_one_four,3.5)*pow(D_one_four,4.))+14.*pow(B_one_four,4.)/(pow(A_one_four,4.5)*pow(D_one_four,5.));
			R_five_one_five=1./(pow(A_one_five,2.5)*pow(D_one_five,3.))+5.*pow(B_one_five,2.)/(pow(A_one_five,3.5)*pow(D_one_five,4.))+14.*pow(B_one_five,4.)/(pow(A_one_five,4.5)*pow(D_one_five,5.));

			R_five_two_two=1./(pow(A_two_two,2.5)*pow(D_two_two,3.));
			R_five_two_three=1./(pow(A_two_three,2.5)*pow(D_two_three,3.))+5.*pow(B_two_three,2.)/(pow(A_two_three,3.5)*pow(D_two_three,4.))+14.*pow(B_two_three,4.)/(pow(A_two_three,4.5)*pow(D_two_three,5.));
			R_five_two_four=1./(pow(A_two_four,2.5)*pow(D_two_four,3.))+5.*pow(B_two_four,2.)/(pow(A_two_four,3.5)*pow(D_two_four,4.))+14.*pow(B_two_four,4.)/(pow(A_two_four,4.5)*pow(D_two_four,5.));
			R_five_two_five=1./(pow(A_two_five,2.5)*pow(D_two_five,3.))+5.*pow(B_two_five,2.)/(pow(A_two_five,3.5)*pow(D_two_five,4.))+14.*pow(B_two_five,4.)/(pow(A_two_five,4.5)*pow(D_two_five,5.));

			R_five_three_three=1./(pow(A_three_three,2.5)*pow(D_three_three,3.));
			R_five_three_four=1./(pow(A_three_four,2.5)*pow(D_three_four,3.))+5.*pow(B_three_four,2.)/(pow(A_three_four,3.5)*pow(D_three_four,4.))+14.*pow(B_three_four,4.)/(pow(A_three_four,4.5)*pow(D_three_four,5.));
			R_five_three_five=1./(pow(A_three_five,2.5)*pow(D_three_five,3.))+5.*pow(B_three_five,2.)/(pow(A_three_five,3.5)*pow(D_three_five,4.))+14.*pow(B_three_five,4.)/(pow(A_three_five,4.5)*pow(D_three_five,5.));

			R_five_four_four=1./(pow(A_four_four,2.5)*pow(D_four_four,3.));
			R_five_four_five=1./(pow(A_four_five,2.5)*pow(D_four_five,3.))+5.*pow(B_four_five,2.)/(pow(A_four_five,3.5)*pow(D_four_five,4.))+14.*pow(B_four_five,4.)/(pow(A_four_five,4.5)*pow(D_four_five,5.));

			R_five_five_five=1./(pow(A_five_five,2.5)*pow(D_five_five,3.));

			/*
			R_six_one_one=1./(pow(A_one_one,3.5)*pow(D_one_one,3.));
			R_six_one_two=1./(pow(A_one_two,3.5)*pow(D_one_two,3.))+7.*pow(B_one_two,2.)/(pow(A_one_two,4.5)*pow(D_one_two,4.))+126.*pow(B_one_two,4.)/(5.*pow(A_one_two,5.5)*pow(D_one_two,5.));
			R_six_one_three=1./(pow(A_one_three,3.5)*pow(D_one_three,3.))+7.*pow(B_one_three,2.)/(pow(A_one_three,4.5)*pow(D_one_three,4.))+126.*pow(B_one_three,4.)/(5.*pow(A_one_three,5.5)*pow(D_one_three,5.));
			R_six_one_four=1./(pow(A_one_four,3.5)*pow(D_one_four,3.))+7.*pow(B_one_four,2.)/(pow(A_one_four,4.5)*pow(D_one_four,4.))+126.*pow(B_one_four,4.)/(5.*pow(A_one_four,5.5)*pow(D_one_four,5.));
			R_six_one_five=1./(pow(A_one_five,3.5)*pow(D_one_five,3.))+7.*pow(B_one_five,2.)/(pow(A_one_five,4.5)*pow(D_one_five,4.))+126.*pow(B_one_five,4.)/(5.*pow(A_one_five,5.5)*pow(D_one_five,5.));

			R_six_two_two=1./(pow(A_two_two,3.5)*pow(D_two_two,3.));
			R_six_two_three=1./(pow(A_two_three,3.5)*pow(D_two_three,3.))+7.*pow(B_two_three,2.)/(pow(A_two_three,4.5)*pow(D_two_three,4.))+126.*pow(B_two_three,4.)/(5.*pow(A_two_three,5.5)*pow(D_two_three,5.));
			R_six_two_four=1./(pow(A_two_four,3.5)*pow(D_two_four,3.))+7.*pow(B_two_four,2.)/(pow(A_two_four,4.5)*pow(D_two_four,4.))+126.*pow(B_two_four,4.)/(5.*pow(A_two_four,5.5)*pow(D_two_four,5.));
			R_six_two_five=1./(pow(A_two_five,3.5)*pow(D_two_five,3.))+7.*pow(B_two_five,2.)/(pow(A_two_five,4.5)*pow(D_two_five,4.))+126.*pow(B_two_five,4.)/(5.*pow(A_two_five,5.5)*pow(D_two_five,5.));

			R_six_three_three=1./(pow(A_three_three,3.5)*pow(D_three_three,3.));
			R_six_three_four=1./(pow(A_three_four,3.5)*pow(D_three_four,3.))+7.*pow(B_three_four,2.)/(pow(A_three_four,4.5)*pow(D_three_four,4.))+126.*pow(B_three_four,4.)/(5.*pow(A_three_four,5.5)*pow(D_three_four,5.));
			R_six_three_five=1./(pow(A_three_five,3.5)*pow(D_three_five,3.))+7.*pow(B_three_five,2.)/(pow(A_three_five,4.5)*pow(D_three_five,4.))+126.*pow(B_three_five,4.)/(5.*pow(A_three_five,5.5)*pow(D_three_five,5.));

			R_six_four_four=1./(pow(A_four_four,3.5)*pow(D_four_four,3.));
			R_six_four_five=1./(pow(A_four_five,3.5)*pow(D_four_five,3.))+7.*pow(B_four_five,2.)/(pow(A_four_five,4.5)*pow(D_four_five,4.))+126.*pow(B_four_five,4.)/(5.*pow(A_four_five,5.5)*pow(D_four_five,5.));

			R_six_five_five=1./(pow(A_five_five,3.5)*pow(D_five_five,3.));


			R_seven_one_one=3./(2.*pow(A_one_one,2.5)*pow(D_one_one,4.));
			R_seven_one_two=3./(2.*pow(A_one_two,2.5)*pow(D_one_two,4.))+10.*pow(B_one_two,2.)/(pow(A_one_two,3.5)*pow(D_one_two,5.))+35.*pow(B_one_two,4.)/(pow(A_one_two,4.5)*pow(D_one_two,6.));
			R_seven_one_three=3./(2.*pow(A_one_three,2.5)*pow(D_one_three,4.))+10.*pow(B_one_three,2.)/(pow(A_one_three,3.5)*pow(D_one_three,5.))+35.*pow(B_one_three,4.)/(pow(A_one_three,4.5)*pow(D_one_three,6.));
			R_seven_one_four=3./(2.*pow(A_one_four,2.5)*pow(D_one_four,4.))+10.*pow(B_one_four,2.)/(pow(A_one_four,3.5)*pow(D_one_four,5.))+35.*pow(B_one_four,4.)/(pow(A_one_four,4.5)*pow(D_one_four,6.));
			R_seven_one_five=3./(2.*pow(A_one_five,2.5)*pow(D_one_five,4.))+10.*pow(B_one_five,2.)/(pow(A_one_five,3.5)*pow(D_one_five,5.))+35.*pow(B_one_five,4.)/(pow(A_one_five,4.5)*pow(D_one_five,6.));

			R_seven_two_two=3./(2.*pow(A_two_two,2.5)*pow(D_two_two,4.));
			R_seven_two_three=3./(2.*pow(A_two_three,2.5)*pow(D_two_three,4.))+10.*pow(B_two_three,2.)/(pow(A_two_three,3.5)*pow(D_two_three,5.))+35.*pow(B_two_three,4.)/(pow(A_two_three,4.5)*pow(D_two_three,6.));
			R_seven_two_four=3./(2.*pow(A_two_four,2.5)*pow(D_two_four,4.))+10.*pow(B_two_four,2.)/(pow(A_two_four,3.5)*pow(D_two_four,5.))+35.*pow(B_two_four,4.)/(pow(A_two_four,4.5)*pow(D_two_four,6.));
			R_seven_two_five=3./(2.*pow(A_two_five,2.5)*pow(D_two_five,4.))+10.*pow(B_two_five,2.)/(pow(A_two_five,3.5)*pow(D_two_five,5.))+35.*pow(B_two_five,4.)/(pow(A_two_five,4.5)*pow(D_two_five,6.));

			R_seven_three_three=3./(2.*pow(A_three_three,2.5)*pow(D_three_three,4.));
			R_seven_three_four=3./(2.*pow(A_three_four,2.5)*pow(D_three_four,4.))+10.*pow(B_three_four,2.)/(pow(A_three_four,3.5)*pow(D_three_four,5.))+35.*pow(B_three_four,4.)/(pow(A_three_four,4.5)*pow(D_three_four,6.));
			R_seven_three_five=3./(2.*pow(A_three_five,2.5)*pow(D_three_five,4.))+10.*pow(B_three_five,2.)/(pow(A_three_five,3.5)*pow(D_three_five,5.))+35.*pow(B_three_five,4.)/(pow(A_three_five,4.5)*pow(D_three_five,6.));

			R_seven_four_four=3./(2.*pow(A_four_four,2.5)*pow(D_four_four,4.));
			R_seven_four_five=3./(2.*pow(A_four_five,2.5)*pow(D_four_five,4.))+10.*pow(B_four_five,2.)/(pow(A_four_five,3.5)*pow(D_four_five,5.))+35.*pow(B_four_five,4.)/(pow(A_four_five,4.5)*pow(D_four_five,6.));

			R_seven_five_five=3./(2.*pow(A_five_five,2.5)*pow(D_five_five,4.));


			R_eight_one_one=1./(2.*pow(A_one_one,1.5)*pow(D_one_one,4.));
			R_eight_one_two=1./(2.*pow(A_one_two,1.5)*pow(D_one_two,4.))+6.*pow(B_one_two,2.)/(pow(A_one_two,2.5)*pow(D_one_two,5.))+25.*pow(B_one_two,4.)/(pow(A_one_two,3.5)*pow(D_one_two,6.));
			R_eight_one_three=1./(2.*pow(A_one_three,1.5)*pow(D_one_three,4.))+6.*pow(B_one_three,2.)/(pow(A_one_three,2.5)*pow(D_one_three,5.))+25.*pow(B_one_three,4.)/(pow(A_one_three,3.5)*pow(D_one_three,6.));
			R_eight_one_four=1./(2.*pow(A_one_four,1.5)*pow(D_one_four,4.))+6.*pow(B_one_four,2.)/(pow(A_one_four,2.5)*pow(D_one_four,5.))+25.*pow(B_one_four,4.)/(pow(A_one_four,3.5)*pow(D_one_four,6.));
			R_eight_one_five=1./(2.*pow(A_one_five,1.5)*pow(D_one_five,4.))+6.*pow(B_one_five,2.)/(pow(A_one_five,2.5)*pow(D_one_five,5.))+25.*pow(B_one_five,4.)/(pow(A_one_five,3.5)*pow(D_one_five,6.));

			R_eight_two_two=1./(2.*pow(A_two_two,1.5)*pow(D_two_two,4.));
			R_eight_two_three=1./(2.*pow(A_two_three,1.5)*pow(D_two_three,4.))+6.*pow(B_two_three,2.)/(pow(A_two_three,2.5)*pow(D_two_three,5.))+25.*pow(B_two_three,4.)/(pow(A_two_three,3.5)*pow(D_two_three,6.));
			R_eight_two_four=1./(2.*pow(A_two_four,1.5)*pow(D_two_four,4.))+6.*pow(B_two_four,2.)/(pow(A_two_four,2.5)*pow(D_two_four,5.))+25.*pow(B_two_four,4.)/(pow(A_two_four,3.5)*pow(D_two_four,6.));
			R_eight_two_five=1./(2.*pow(A_two_five,1.5)*pow(D_two_five,4.))+6.*pow(B_two_five,2.)/(pow(A_two_five,2.5)*pow(D_two_five,5.))+25.*pow(B_two_five,4.)/(pow(A_two_five,3.5)*pow(D_two_five,6.));

			R_eight_three_three=1./(2.*pow(A_three_three,1.5)*pow(D_three_three,4.));
			R_eight_three_four=1./(2.*pow(A_three_four,1.5)*pow(D_three_four,4.))+6.*pow(B_three_four,2.)/(pow(A_three_four,2.5)*pow(D_three_four,5.))+25.*pow(B_three_four,4.)/(pow(A_three_four,3.5)*pow(D_three_four,6.));
			R_eight_three_five=1./(2.*pow(A_three_five,1.5)*pow(D_three_five,4.))+6.*pow(B_three_five,2.)/(pow(A_three_five,2.5)*pow(D_three_five,5.))+25.*pow(B_three_five,4.)/(pow(A_three_five,3.5)*pow(D_three_five,6.));

			R_eight_four_four=1./(2.*pow(A_four_four,1.5)*pow(D_four_four,4.));
			R_eight_four_five=1./(2.*pow(A_four_five,1.5)*pow(D_four_five,4.))+6.*pow(B_four_five,2.)/(pow(A_four_five,2.5)*pow(D_four_five,5.))+25.*pow(B_four_five,4.)/(pow(A_four_five,3.5)*pow(D_four_five,6.));

			R_eight_five_five=1./(2.*pow(A_five_five,1.5)*pow(D_five_five,4.));


			R_nine_one_one=1./(pow(A_one_one,2.5)*pow(D_one_one,3.));
			R_nine_one_two=1./(pow(A_one_two,2.5)*pow(D_one_two,3.))+15.*pow(B_one_two,2.)/(pow(A_one_two,3.5)*pow(D_one_two,4.))+70.*pow(B_one_two,4.)/(pow(A_one_two,4.5)*pow(D_one_two,5.));
			R_nine_one_three=1./(pow(A_one_three,2.5)*pow(D_one_three,3.))+15.*pow(B_one_three,2.)/(pow(A_one_three,3.5)*pow(D_one_three,4.))+70.*pow(B_one_three,4.)/(pow(A_one_three,4.5)*pow(D_one_three,5.));
			R_nine_one_four=1./(pow(A_one_four,2.5)*pow(D_one_four,3.))+15.*pow(B_one_four,2.)/(pow(A_one_four,3.5)*pow(D_one_four,4.))+70.*pow(B_one_four,4.)/(pow(A_one_four,4.5)*pow(D_one_four,5.));
			R_nine_one_five=1./(pow(A_one_five,2.5)*pow(D_one_five,3.))+15.*pow(B_one_five,2.)/(pow(A_one_five,3.5)*pow(D_one_five,4.))+70.*pow(B_one_five,4.)/(pow(A_one_five,4.5)*pow(D_one_five,5.));

			R_nine_two_two=1./(pow(A_two_two,2.5)*pow(D_two_two,3.));
			R_nine_two_three=1./(pow(A_two_three,2.5)*pow(D_two_three,3.))+15.*pow(B_two_three,2.)/(pow(A_two_three,3.5)*pow(D_two_three,4.))+70.*pow(B_two_three,4.)/(pow(A_two_three,4.5)*pow(D_two_three,5.));
			R_nine_two_four=1./(pow(A_two_four,2.5)*pow(D_two_four,3.))+15.*pow(B_two_four,2.)/(pow(A_two_four,3.5)*pow(D_two_four,4.))+70.*pow(B_two_four,4.)/(pow(A_two_four,4.5)*pow(D_two_four,5.));
			R_nine_two_five=1./(pow(A_two_five,2.5)*pow(D_two_five,3.))+15.*pow(B_two_five,2.)/(pow(A_two_five,3.5)*pow(D_two_five,4.))+70.*pow(B_two_five,4.)/(pow(A_two_five,4.5)*pow(D_two_five,5.));

			R_nine_three_three=1./(pow(A_three_three,2.5)*pow(D_three_three,3.));
			R_nine_three_four=1./(pow(A_three_four,2.5)*pow(D_three_four,3.))+15.*pow(B_three_four,2.)/(pow(A_three_four,3.5)*pow(D_three_four,4.))+70.*pow(B_three_four,4.)/(pow(A_three_four,4.5)*pow(D_three_four,5.));
			R_nine_three_five=1./(pow(A_three_five,2.5)*pow(D_three_five,3.))+15.*pow(B_three_five,2.)/(pow(A_three_five,3.5)*pow(D_three_five,4.))+70.*pow(B_three_five,4.)/(pow(A_three_five,4.5)*pow(D_three_five,5.));

			R_nine_four_four=1./(pow(A_four_four,2.5)*pow(D_four_four,3.));
			R_nine_four_five=1./(pow(A_four_five,2.5)*pow(D_four_five,3.))+15.*pow(B_four_five,2.)/(pow(A_four_five,3.5)*pow(D_four_five,4.))+70.*pow(B_four_five,4.)/(pow(A_four_five,4.5)*pow(D_four_five,5.));

			R_nine_five_five=1./(pow(A_five_five,2.5)*pow(D_five_five,3.));


			R_ten_one_one=1./(pow(A_one_one,2.5)*pow(D_one_one,2.5));
			R_ten_one_two=1./(pow(A_one_two,2.5)*pow(D_one_two,2.5))+25.*pow(B_one_two,2.)/(2.*pow(A_one_two,3.5)*pow(D_one_two,3.5))+1225.*pow(B_one_two,4.)/(24.*pow(A_one_two,4.5)*pow(D_one_two,4.5));
			R_ten_one_three=1./(pow(A_one_three,2.5)*pow(D_one_three,2.5))+25.*pow(B_one_three,2.)/(2.*pow(A_one_three,3.5)*pow(D_one_three,3.5))+1225.*pow(B_one_three,4.)/(24.*pow(A_one_three,4.5)*pow(D_one_three,4.5));
			R_ten_one_four=1./(pow(A_one_four,2.5)*pow(D_one_four,2.5))+25.*pow(B_one_four,2.)/(2.*pow(A_one_four,3.5)*pow(D_one_four,3.5))+1225.*pow(B_one_four,4.)/(24.*pow(A_one_four,4.5)*pow(D_one_four,4.5));
			R_ten_one_five=1./(pow(A_one_five,2.5)*pow(D_one_five,2.5))+25.*pow(B_one_five,2.)/(2.*pow(A_one_five,3.5)*pow(D_one_five,3.5))+1225.*pow(B_one_five,4.)/(24.*pow(A_one_five,4.5)*pow(D_one_five,4.5));

			R_ten_two_two=1./(pow(A_two_two,2.5)*pow(D_two_two,2.5));
			R_ten_two_three=1./(pow(A_two_three,2.5)*pow(D_two_three,2.5))+25.*pow(B_two_three,2.)/(2.*pow(A_two_three,3.5)*pow(D_two_three,3.5))+1225.*pow(B_two_three,4.)/(24.*pow(A_two_three,4.5)*pow(D_two_three,4.5));
			R_ten_two_four=1./(pow(A_two_four,2.5)*pow(D_two_four,2.5))+25.*pow(B_two_four,2.)/(2.*pow(A_two_four,3.5)*pow(D_two_four,3.5))+1225.*pow(B_two_four,4.)/(24.*pow(A_two_four,4.5)*pow(D_two_four,4.5));
			R_ten_two_five=1./(pow(A_two_five,2.5)*pow(D_two_five,2.5))+25.*pow(B_two_five,2.)/(2.*pow(A_two_five,3.5)*pow(D_two_five,3.5))+1225.*pow(B_two_five,4.)/(24.*pow(A_two_five,4.5)*pow(D_two_five,4.5));

			R_ten_three_three=1./(pow(A_three_three,2.5)*pow(D_three_three,2.5));
			R_ten_three_four=1./(pow(A_three_four,2.5)*pow(D_three_four,2.5))+25.*pow(B_three_four,2.)/(2.*pow(A_three_four,3.5)*pow(D_three_four,3.5))+1225.*pow(B_three_four,4.)/(24.*pow(A_three_four,4.5)*pow(D_three_four,4.5));
			R_ten_three_five=1./(pow(A_three_five,2.5)*pow(D_three_five,2.5))+25.*pow(B_three_five,2.)/(2.*pow(A_three_five,3.5)*pow(D_three_five,3.5))+1225.*pow(B_three_five,4.)/(24.*pow(A_three_five,4.5)*pow(D_three_five,4.5));

			R_ten_four_four=1./(pow(A_four_four,2.5)*pow(D_four_four,2.5));
			R_ten_four_five=1./(pow(A_four_five,2.5)*pow(D_four_five,2.5))+25.*pow(B_four_five,2.)/(2.*pow(A_four_five,3.5)*pow(D_four_five,3.5))+1225.*pow(B_four_five,4.)/(24.*pow(A_four_five,4.5)*pow(D_four_five,4.5));

			R_ten_five_five=1./(pow(A_five_five,2.5)*pow(D_five_five,2.5));
			*/
			
			dof_over_d_sum=C_VOF(cell,subthread_one)/d_one+C_VOF(cell,subthread_two)/d_two+C_VOF(cell,subthread_three)/d_three+C_VOF(cell,subthread_four)/d_four+C_VOF(cell,subthread_five)/d_five;

			g_ii_one_one=1./(1.-C_VOF(cell,subthread_one)-C_VOF(cell,subthread_one))+3.*d_one*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_one)-C_VOF(cell,subthread_one)),2.));
			g_ii_one_two=1./(1.-C_VOF(cell,subthread_one)-C_VOF(cell,subthread_two))+3.*d_one*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_one)-C_VOF(cell,subthread_two)),2.));
			g_ii_one_three=1./(1.-C_VOF(cell,subthread_one)-C_VOF(cell,subthread_three))+3.*d_one*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_one)-C_VOF(cell,subthread_three)),2.));
			g_ii_one_four=1./(1.-C_VOF(cell,subthread_one)-C_VOF(cell,subthread_four))+3.*d_one*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_one)-C_VOF(cell,subthread_four)),2.));
			g_ii_one_five=1./(1.-C_VOF(cell,subthread_one)-C_VOF(cell,subthread_five))+3.*d_one*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_one)-C_VOF(cell,subthread_five)),2.));


			g_ii_two_one=1./(1.-C_VOF(cell,subthread_two)-C_VOF(cell,subthread_one))+3.*d_two*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_two)-C_VOF(cell,subthread_one)),2.));
			g_ii_two_two=1./(1.-C_VOF(cell,subthread_two)-C_VOF(cell,subthread_two))+3.*d_two*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_two)-C_VOF(cell,subthread_two)),2.));
			g_ii_two_three=1./(1.-C_VOF(cell,subthread_two)-C_VOF(cell,subthread_three))+3.*d_two*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_two)-C_VOF(cell,subthread_three)),2.));
			g_ii_two_four=1./(1.-C_VOF(cell,subthread_two)-C_VOF(cell,subthread_four))+3.*d_two*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_two)-C_VOF(cell,subthread_four)),2.));
			g_ii_two_five=1./(1.-C_VOF(cell,subthread_two)-C_VOF(cell,subthread_five))+3.*d_two*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_two)-C_VOF(cell,subthread_five)),2.));


			g_ii_three_one=1./(1.-C_VOF(cell,subthread_three)-C_VOF(cell,subthread_one))+3.*d_three*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_three)-C_VOF(cell,subthread_one)),2.));
			g_ii_three_two=1./(1.-C_VOF(cell,subthread_three)-C_VOF(cell,subthread_two))+3.*d_three*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_three)-C_VOF(cell,subthread_two)),2.));
			g_ii_three_three=1./(1.-C_VOF(cell,subthread_three)-C_VOF(cell,subthread_three))+3.*d_three*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_three)-C_VOF(cell,subthread_three)),2.));
			g_ii_three_four=1./(1.-C_VOF(cell,subthread_three)-C_VOF(cell,subthread_four))+3.*d_three*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_three)-C_VOF(cell,subthread_four)),2.));
			g_ii_three_five=1./(1.-C_VOF(cell,subthread_three)-C_VOF(cell,subthread_five))+3.*d_three*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_three)-C_VOF(cell,subthread_five)),2.));


			g_ii_four_one=1./(1.-C_VOF(cell,subthread_four)-C_VOF(cell,subthread_one))+3.*d_four*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_four)-C_VOF(cell,subthread_one)),2.));
			g_ii_four_two=1./(1.-C_VOF(cell,subthread_four)-C_VOF(cell,subthread_two))+3.*d_four*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_four)-C_VOF(cell,subthread_two)),2.));
			g_ii_four_three=1./(1.-C_VOF(cell,subthread_four)-C_VOF(cell,subthread_three))+3.*d_four*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_four)-C_VOF(cell,subthread_three)),2.));
			g_ii_four_four=1./(1.-C_VOF(cell,subthread_four)-C_VOF(cell,subthread_four))+3.*d_four*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_four)-C_VOF(cell,subthread_four)),2.));
			g_ii_four_five=1./(1.-C_VOF(cell,subthread_four)-C_VOF(cell,subthread_five))+3.*d_four*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_four)-C_VOF(cell,subthread_five)),2.));


			g_ii_five_one=1./(1.-C_VOF(cell,subthread_five)-C_VOF(cell,subthread_one))+3.*d_five*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_five)-C_VOF(cell,subthread_one)),2.));
			g_ii_five_two=1./(1.-C_VOF(cell,subthread_five)-C_VOF(cell,subthread_two))+3.*d_five*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_five)-C_VOF(cell,subthread_two)),2.));
			g_ii_five_three=1./(1.-C_VOF(cell,subthread_five)-C_VOF(cell,subthread_three))+3.*d_five*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_five)-C_VOF(cell,subthread_three)),2.));
			g_ii_five_four=1./(1.-C_VOF(cell,subthread_five)-C_VOF(cell,subthread_four))+3.*d_five*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_five)-C_VOF(cell,subthread_four)),2.));
			g_ii_five_five=1./(1.-C_VOF(cell,subthread_five)-C_VOF(cell,subthread_five))+3.*d_five*dof_over_d_sum/(2.*pow((1.-C_VOF(cell,subthread_five)-C_VOF(cell,subthread_five)),2.));

			g_one_one=g_ii_one_one;
			g_one_two=(d_two*g_ii_one_two+d_one*g_ii_two_one)/(d_one+d_two);
			g_one_three=(d_three*g_ii_one_three+d_one*g_ii_three_one)/(d_one+d_three);
			g_one_four=(d_four*g_ii_one_four+d_one*g_ii_four_one)/(d_one+d_four);
			g_one_five=(d_five*g_ii_one_five+d_one*g_ii_five_one)/(d_one+d_five);

			g_two_two=g_ii_two_two;
			g_two_three=(d_three*g_ii_two_three+d_two*g_ii_three_two)/(d_two+d_three);
			g_two_four=(d_four*g_ii_two_four+d_two*g_ii_four_two)/(d_two+d_four);
			g_two_five=(d_five*g_ii_two_five+d_two*g_ii_five_two)/(d_two+d_five);

			g_three_three=g_ii_three_three;
			g_three_four=(d_four*g_ii_three_four+d_three*g_ii_four_three)/(d_three+d_four);
			g_three_five=(d_five*g_ii_three_five+d_three*g_ii_five_three)/(d_three+d_five);

			g_four_four=g_ii_four_four;
			g_four_five=(d_five*g_ii_four_five+d_four*g_ii_five_four)/(d_four+d_five);

			g_five_five=g_ii_five_five;

			
			P_one_one_c=pow((d_one+d_one)/2.,3.)/48.*g_one_one*m_one*m_one/(m_one+m_one)*pow((m_one*m_one/(theta_one*theta_one)),1.5)*n_one*n_one*(1.+e_one_one)*PI*R_zero_one_one;
			P_one_two_c=pow((d_one+d_two)/2.,3.)/48.*g_one_two*m_one*m_two/(m_one+m_two)*pow((m_one*m_two/(theta_one*theta_two)),1.5)*n_one*n_two*(1.+e_one_two)*PI*R_zero_one_two;
			P_one_three_c=pow((d_one+d_three)/2.,3.)/48.*g_one_three*m_one*m_three/(m_one+m_three)*pow((m_one*m_three/(theta_one*theta_three)),1.5)*n_one*n_three*(1.+e_one_three)*PI*R_zero_one_three;
			P_one_four_c=pow((d_one+d_four)/2.,3.)/48.*g_one_four*m_one*m_four/(m_one+m_four)*pow((m_one*m_four/(theta_one*theta_four)),1.5)*n_one*n_four*(1.+e_one_four)*PI*R_zero_one_four;
			P_one_five_c=pow((d_one+d_five)/2.,3.)/48.*g_one_five*m_one*m_five/(m_one+m_five)*pow((m_one*m_five/(theta_one*theta_five)),1.5)*n_one*n_five*(1.+e_one_five)*PI*R_zero_one_five;

			P_two_two_c=pow((d_two+d_two)/2.,3.)/48.*g_two_two*m_two*m_two/(m_two+m_two)*pow((m_two*m_two/(theta_two*theta_two)),1.5)*n_two*n_two*(1.+e_two_two)*PI*R_zero_two_two;
			P_two_three_c=pow((d_two+d_three)/2.,3.)/48.*g_two_three*m_two*m_three/(m_two+m_three)*pow((m_two*m_three/(theta_two*theta_three)),1.5)*n_two*n_three*(1.+e_two_three)*PI*R_zero_two_three;
			P_two_four_c=pow((d_two+d_four)/2.,3.)/48.*g_two_four*m_two*m_four/(m_two+m_four)*pow((m_two*m_four/(theta_two*theta_four)),1.5)*n_two*n_four*(1.+e_two_four)*PI*R_zero_two_four;
			P_two_five_c=pow((d_two+d_five)/2.,3.)/48.*g_two_five*m_two*m_five/(m_two+m_five)*pow((m_two*m_five/(theta_two*theta_five)),1.5)*n_two*n_five*(1.+e_two_five)*PI*R_zero_two_five;

			P_three_three_c=pow((d_three+d_three)/2.,3.)/48.*g_three_three*m_three*m_three/(m_three+m_three)*pow((m_three*m_three/(theta_three*theta_three)),1.5)*n_three*n_three*(1.+e_three_three)*PI*R_zero_three_three;
			P_three_four_c=pow((d_three+d_four)/2.,3.)/48.*g_three_four*m_three*m_four/(m_three+m_four)*pow((m_three*m_four/(theta_three*theta_four)),1.5)*n_three*n_four*(1.+e_three_four)*PI*R_zero_three_four;
			P_three_five_c=pow((d_three+d_five)/2.,3.)/48.*g_three_five*m_three*m_five/(m_three+m_five)*pow((m_three*m_five/(theta_three*theta_five)),1.5)*n_three*n_five*(1.+e_three_five)*PI*R_zero_three_five;

			P_four_four_c=pow((d_four+d_four)/2.,3.)/48.*g_four_four*m_four*m_four/(m_four+m_four)*pow((m_four*m_four/(theta_four*theta_four)),1.5)*n_four*n_four*(1.+e_four_four)*PI*R_zero_four_four;
			P_four_five_c=pow((d_four+d_five)/2.,3.)/48.*g_four_five*m_four*m_five/(m_four+m_five)*pow((m_four*m_five/(theta_four*theta_five)),1.5)*n_four*n_five*(1.+e_four_five)*PI*R_zero_four_five;

			P_five_five_c=pow((d_five+d_five)/2.,3.)/48.*g_five_five*m_five*m_five/(m_five+m_five)*pow((m_five*m_five/(theta_five*theta_five)),1.5)*n_five*n_five*(1.+e_five_five)*PI*R_zero_five_five;

			P_one=P_one_k+P_one_one_c+P_one_two_c+P_one_three_c+P_one_four_c+P_one_five_c;
			P_two=P_two_k+P_one_two_c+P_two_two_c+P_two_three_c+P_two_four_c+P_two_five_c;
			P_three=P_three_k+P_one_three_c+P_two_three_c+P_three_three_c+P_three_four_c+P_three_five_c;
			P_four=P_four_k+P_one_four_c+P_two_four_c+P_three_four_c+P_four_four_c+P_four_five_c;
			P_five=P_five_k+P_one_five_c+P_two_five_c+P_three_five_c+P_four_five_c+P_five_five_c;

			N_one_one=3./4.*pow((d_one+d_one)/2.,2.)*(e_one_one+1.)*g_one_one*n_one*n_one*pow(m_one*m_one/(theta_one*theta_one),1.5)*m_one*m_one/(m_one+m_one)*((e_one_one-1.)*m_one/(m_one+m_one)*sqrt(PI)/6.*R_one_one_one);
			N_one_two=3./4.*pow((d_one+d_two)/2.,2.)*(e_one_two+1.)*g_one_two*n_one*n_two*pow(m_one*m_two/(theta_one*theta_two),1.5)*m_one*m_two/(m_one+m_two)*(B_one_two*sqrt(PI)*R_five_one_two+(e_one_two-1.)*m_two/(m_one+m_two)*sqrt(PI)/6.*R_one_one_two);
			N_one_three=3./4.*pow((d_one+d_three)/2.,2.)*(e_one_three+1.)*g_one_three*n_one*n_three*pow(m_one*m_three/(theta_one*theta_three),1.5)*m_one*m_three/(m_one+m_three)*(B_one_three*sqrt(PI)*R_five_one_three+(e_one_three-1.)*m_three/(m_one+m_three)*sqrt(PI)/6.*R_one_one_three);
			N_one_four=3./4.*pow((d_one+d_four)/2.,2.)*(e_one_four+1.)*g_one_four*n_one*n_four*pow(m_one*m_four/(theta_one*theta_four),1.5)*m_one*m_four/(m_one+m_four)*(B_one_four*sqrt(PI)*R_five_one_four+(e_one_four-1.)*m_four/(m_one+m_four)*sqrt(PI)/6.*R_one_one_four);
			N_one_five=3./4.*pow((d_one+d_five)/2.,2.)*(e_one_five+1.)*g_one_five*n_one*n_five*pow(m_one*m_five/(theta_one*theta_five),1.5)*m_one*m_five/(m_one+m_five)*(B_one_five*sqrt(PI)*R_five_one_five+(e_one_five-1.)*m_five/(m_one+m_five)*sqrt(PI)/6.*R_one_one_five);

			N_two_one=3./4.*pow((d_two+d_one)/2.,2.)*(e_one_two+1.)*g_one_two*n_two*n_one*pow(m_two*m_one/(theta_two*theta_one),1.5)*m_two*m_one/(m_two+m_one)*(B_two_one*sqrt(PI)*R_five_one_two+(e_one_two-1.)*m_one/(m_two+m_one)*sqrt(PI)/6.*R_one_one_two);
			N_two_two=3./4.*pow((d_two+d_two)/2.,2.)*(e_two_two+1.)*g_two_two*n_two*n_two*pow(m_two*m_two/(theta_two*theta_two),1.5)*m_two*m_two/(m_two+m_two)*((e_two_two-1.)*m_two/(m_two+m_two)*sqrt(PI)/6.*R_one_two_two);
			N_two_three=3./4.*pow((d_two+d_three)/2.,2.)*(e_two_three+1.)*g_two_three*n_two*n_three*pow(m_two*m_three/(theta_two*theta_three),1.5)*m_two*m_three/(m_two+m_three)*(B_two_three*sqrt(PI)*R_five_two_three+(e_two_three-1.)*m_three/(m_two+m_three)*sqrt(PI)/6.*R_one_two_three);
			N_two_four=3./4.*pow((d_two+d_four)/2.,2.)*(e_two_four+1.)*g_two_four*n_two*n_four*pow(m_two*m_four/(theta_two*theta_four),1.5)*m_two*m_four/(m_two+m_four)*(B_two_four*sqrt(PI)*R_five_two_four+(e_two_four-1.)*m_four/(m_two+m_four)*sqrt(PI)/6.*R_one_two_four);
			N_two_five=3./4.*pow((d_two+d_five)/2.,2.)*(e_two_five+1.)*g_two_five*n_two*n_five*pow(m_two*m_five/(theta_two*theta_five),1.5)*m_two*m_five/(m_two+m_five)*(B_two_five*sqrt(PI)*R_five_two_five+(e_two_five-1.)*m_five/(m_two+m_five)*sqrt(PI)/6.*R_one_two_five);

			N_three_one=3./4.*pow((d_three+d_one)/2.,2.)*(e_one_three+1.)*g_one_three*n_three*n_one*pow(m_three*m_one/(theta_three*theta_one),1.5)*m_three*m_one/(m_three+m_one)*(B_three_one*sqrt(PI)*R_five_one_three+(e_one_three-1.)*m_one/(m_three+m_one)*sqrt(PI)/6.*R_one_one_three);
			N_three_two=3./4.*pow((d_three+d_two)/2.,2.)*(e_two_three+1.)*g_two_three*n_three*n_two*pow(m_three*m_two/(theta_three*theta_two),1.5)*m_three*m_two/(m_three+m_two)*(B_three_two*sqrt(PI)*R_five_two_three+(e_two_three-1.)*m_two/(m_three+m_two)*sqrt(PI)/6.*R_one_two_three);
			N_three_three=3./4.*pow((d_three+d_three)/2.,2.)*(e_three_three+1.)*g_three_three*n_three*n_three*pow(m_three*m_three/(theta_three*theta_three),1.5)*m_three*m_three/(m_three+m_three)*((e_three_three-1.)*m_three/(m_three+m_three)*sqrt(PI)/6.*R_one_three_three);
			N_three_four=3./4.*pow((d_three+d_four)/2.,2.)*(e_three_four+1.)*g_three_four*n_three*n_four*pow(m_three*m_four/(theta_three*theta_four),1.5)*m_three*m_four/(m_three+m_four)*(B_three_four*sqrt(PI)*R_five_three_four+(e_three_four-1.)*m_four/(m_three+m_four)*sqrt(PI)/6.*R_one_three_four);
			N_three_five=3./4.*pow((d_three+d_five)/2.,2.)*(e_three_five+1.)*g_three_five*n_three*n_five*pow(m_three*m_five/(theta_three*theta_five),1.5)*m_three*m_five/(m_three+m_five)*(B_three_five*sqrt(PI)*R_five_three_five+(e_three_five-1.)*m_five/(m_three+m_five)*sqrt(PI)/6.*R_one_three_five);

			N_four_one=3./4.*pow((d_four+d_one)/2.,2.)*(e_one_four+1.)*g_one_four*n_four*n_one*pow(m_four*m_one/(theta_four*theta_one),1.5)*m_four*m_one/(m_four+m_one)*(B_four_one*sqrt(PI)*R_five_one_four+(e_one_four-1.)*m_one/(m_four+m_one)*sqrt(PI)/6.*R_one_one_four);
			N_four_two=3./4.*pow((d_four+d_two)/2.,2.)*(e_two_four+1.)*g_two_four*n_four*n_two*pow(m_four*m_two/(theta_four*theta_two),1.5)*m_four*m_two/(m_four+m_two)*(B_four_two*sqrt(PI)*R_five_two_four+(e_two_four-1.)*m_two/(m_four+m_two)*sqrt(PI)/6.*R_one_two_four);
			N_four_three=3./4.*pow((d_four+d_three)/2.,2.)*(e_three_four+1.)*g_three_four*n_four*n_three*pow(m_four*m_three/(theta_four*theta_three),1.5)*m_four*m_three/(m_four+m_three)*(B_four_three*sqrt(PI)*R_five_three_four+(e_three_four-1.)*m_three/(m_four+m_three)*sqrt(PI)/6.*R_one_three_four);
			N_four_four=3./4.*pow((d_four+d_four)/2.,2.)*(e_four_four+1.)*g_four_four*n_four*n_four*pow(m_four*m_four/(theta_four*theta_four),1.5)*m_four*m_four/(m_four+m_four)*((e_four_four-1.)*m_four/(m_four+m_four)*sqrt(PI)/6.*R_one_four_four);
			N_four_five=3./4.*pow((d_four+d_five)/2.,2.)*(e_four_five+1.)*g_four_five*n_four*n_five*pow(m_four*m_five/(theta_four*theta_five),1.5)*m_four*m_five/(m_four+m_five)*(B_four_five*sqrt(PI)*R_five_four_five+(e_four_five-1.)*m_five/(m_four+m_five)*sqrt(PI)/6.*R_one_four_five);

			N_five_one=3./4.*pow((d_five+d_one)/2.,2.)*(e_one_five+1.)*g_one_five*n_five*n_one*pow(m_five*m_one/(theta_five*theta_one),1.5)*m_five*m_one/(m_five+m_one)*(B_five_one*sqrt(PI)*R_five_one_five+(e_one_five-1.)*m_one/(m_five+m_one)*sqrt(PI)/6.*R_one_one_five);
			N_five_two=3./4.*pow((d_five+d_two)/2.,2.)*(e_two_five+1.)*g_two_five*n_five*n_two*pow(m_five*m_two/(theta_five*theta_two),1.5)*m_five*m_two/(m_five+m_two)*(B_five_two*sqrt(PI)*R_five_two_five+(e_two_five-1.)*m_two/(m_five+m_two)*sqrt(PI)/6.*R_one_two_five);
			N_five_three=3./4.*pow((d_five+d_three)/2.,2.)*(e_three_five+1.)*g_three_five*n_five*n_three*pow(m_five*m_three/(theta_five*theta_three),1.5)*m_five*m_three/(m_five+m_three)*(B_five_three*sqrt(PI)*R_five_three_five+(e_three_five-1.)*m_three/(m_five+m_three)*sqrt(PI)/6.*R_one_three_five);
			N_five_four=3./4.*pow((d_five+d_four)/2.,2.)*(e_four_five+1.)*g_four_five*n_five*n_four*pow(m_five*m_four/(theta_five*theta_four),1.5)*m_five*m_four/(m_five+m_four)*(B_five_four*sqrt(PI)*R_five_four_five+(e_four_five-1.)*m_four/(m_five+m_four)*sqrt(PI)/6.*R_one_four_five);
			N_five_five=3./4.*pow((d_five+d_five)/2.,2.)*(e_five_five+1.)*g_five_five*n_five*n_five*pow(m_five*m_five/(theta_five*theta_five),1.5)*m_five*m_five/(m_five+m_five)*((e_five_five-1.)*m_five/(m_five+m_five)*sqrt(PI)/6.*R_one_five_five);

			N_one=N_one_one+N_one_two+N_one_three+N_one_four+N_one_five;
			N_two=N_two_one+N_two_two+N_two_three+N_two_four+N_two_five;
			N_three=N_three_one+N_three_two+N_three_three+N_three_four+N_three_five;
			N_four=N_four_one+N_four_two+N_four_three+N_four_four+N_four_five;
			N_five=N_five_one+N_five_two+N_five_three+N_five_four+N_five_five;

			k_one=75./(64.*d_one*d_one)*(1./g_one_one+3.*pow((1.+e_one_one),2.)/5.*C_VOF(cell,subthread_one))*(1.+3./5.*pow((1.+e_one_one),2.)*g_one_one*C_VOF(cell,subthread_one))*sqrt(theta_one/(m_one*PI));
			k_two=75./(64.*d_two*d_two)*(1./g_two_two+3.*pow((1.+e_two_two),2.)/5.*C_VOF(cell,subthread_two))*(1.+3./5.*pow((1.+e_two_two),2.)*g_two_two*C_VOF(cell,subthread_two))*sqrt(theta_two/(m_two*PI));
			k_three=75./(64.*d_three*d_three)*(1./g_three_three+3.*pow((1.+e_three_three),2.)/5.*C_VOF(cell,subthread_three))*(1.+3./5.*pow((1.+e_three_three),2.)*g_three_three*C_VOF(cell,subthread_three))*sqrt(theta_three/(m_three*PI));
			k_four=75./(64.*d_four*d_four)*(1./g_four_four+3.*pow((1.+e_four_four),2.)/5.*C_VOF(cell,subthread_four))*(1.+3./5.*pow((1.+e_four_four),2.)*g_four_four*C_VOF(cell,subthread_four))*sqrt(theta_four/(m_four*PI));
			k_five=75./(64.*d_five*d_five)*(1./g_five_five+3.*pow((1.+e_five_five),2.)/5.*C_VOF(cell,subthread_five))*(1.+3./5.*pow((1.+e_five_five),2.)*g_five_five*C_VOF(cell,subthread_five))*sqrt(theta_five/(m_five*PI));

			C_Dip_one_two=pow((d_one+d_two)/2.,2.)/4.*m_one*m_two/(m_one+m_two)*g_one_two*(1.+e_one_two)*n_one*n_two*pow((m_one*m_two)/(theta_one*theta_two),1.5)*sqrt(PI)*R_two_one_two;
			C_Dip_one_three=pow((d_one+d_three)/2.,2.)/4.*m_one*m_three/(m_one+m_three)*g_one_three*(1.+e_one_three)*n_one*n_three*pow((m_one*m_three)/(theta_one*theta_three),1.5)*sqrt(PI)*R_two_one_three;
			C_Dip_one_four=pow((d_one+d_four)/2.,2.)/4.*m_one*m_four/(m_one+m_four)*g_one_four*(1.+e_one_four)*n_one*n_four*pow((m_one*m_four)/(theta_one*theta_four),1.5)*sqrt(PI)*R_two_one_four;
			C_Dip_one_five=pow((d_one+d_five)/2.,2.)/4.*m_one*m_five/(m_one+m_five)*g_one_five*(1.+e_one_five)*n_one*n_five*pow((m_one*m_five)/(theta_one*theta_five),1.5)*sqrt(PI)*R_two_one_five;

			C_Dip_two_three=pow((d_two+d_three)/2.,2.)/4.*m_two*m_three/(m_two+m_three)*g_two_three*(1.+e_two_three)*n_two*n_three*pow((m_two*m_three)/(theta_two*theta_three),1.5)*sqrt(PI)*R_two_two_three;
			C_Dip_two_four=pow((d_two+d_four)/2.,2.)/4.*m_two*m_four/(m_two+m_four)*g_two_four*(1.+e_two_four)*n_two*n_four*pow((m_two*m_four)/(theta_two*theta_four),1.5)*sqrt(PI)*R_two_two_four;
			C_Dip_two_five=pow((d_two+d_five)/2.,2.)/4.*m_two*m_five/(m_two+m_five)*g_two_five*(1.+e_two_five)*n_two*n_five*pow((m_two*m_five)/(theta_two*theta_five),1.5)*sqrt(PI)*R_two_two_five;

			C_Dip_three_four=pow((d_three+d_four)/2.,2.)/4.*m_three*m_four/(m_three+m_four)*g_three_four*(1.+e_three_four)*n_three*n_four*pow((m_three*m_four)/(theta_three*theta_four),1.5)*sqrt(PI)*R_two_three_four;
			C_Dip_three_five=pow((d_three+d_five)/2.,2.)/4.*m_three*m_five/(m_three+m_five)*g_three_five*(1.+e_three_five)*n_three*n_five*pow((m_three*m_five)/(theta_three*theta_five),1.5)*sqrt(PI)*R_two_three_five;

			C_Dip_four_five=pow((d_four+d_five)/2.,2.)/4.*m_four*m_five/(m_four+m_five)*g_four_five*(1.+e_four_five)*n_four*n_five*pow((m_four*m_five)/(theta_four*theta_five),1.5)*sqrt(PI)*R_two_four_five;

			F_D_one_x=C_Dip_one_two*(C_U(cell,subthread_two)-C_U(cell,subthread_one))+C_Dip_one_three*(C_U(cell,subthread_three)-C_U(cell,subthread_one))+C_Dip_one_four*(C_U(cell,subthread_four)-C_U(cell,subthread_one))+C_Dip_one_five*(C_U(cell,subthread_five)-C_U(cell,subthread_one));
			F_D_two_x=C_Dip_one_two*(C_U(cell,subthread_one)-C_U(cell,subthread_two))+C_Dip_two_three*(C_U(cell,subthread_three)-C_U(cell,subthread_two))+C_Dip_two_four*(C_U(cell,subthread_four)-C_U(cell,subthread_two))+C_Dip_two_five*(C_U(cell,subthread_five)-C_U(cell,subthread_two));
			F_D_three_x=C_Dip_one_three*(C_U(cell,subthread_one)-C_U(cell,subthread_three))+C_Dip_two_three*(C_U(cell,subthread_two)-C_U(cell,subthread_three))+C_Dip_three_four*(C_U(cell,subthread_four)-C_U(cell,subthread_three))+C_Dip_three_five*(C_U(cell,subthread_five)-C_U(cell,subthread_three));
			F_D_four_x=C_Dip_one_four*(C_U(cell,subthread_one)-C_U(cell,subthread_four))+C_Dip_two_four*(C_U(cell,subthread_two)-C_U(cell,subthread_four))+C_Dip_three_four*(C_U(cell,subthread_three)-C_U(cell,subthread_four))+C_Dip_four_five*(C_U(cell,subthread_five)-C_U(cell,subthread_four));
			F_D_five_x=C_Dip_one_five*(C_U(cell,subthread_one)-C_U(cell,subthread_five))+C_Dip_two_five*(C_U(cell,subthread_two)-C_U(cell,subthread_five))+C_Dip_three_five*(C_U(cell,subthread_three)-C_U(cell,subthread_five))+C_Dip_four_five*(C_U(cell,subthread_four)-C_U(cell,subthread_five));

			F_D_one_y=C_Dip_one_two*(C_V(cell,subthread_two)-C_V(cell,subthread_one))+C_Dip_one_three*(C_V(cell,subthread_three)-C_V(cell,subthread_one))+C_Dip_one_four*(C_V(cell,subthread_four)-C_V(cell,subthread_one))+C_Dip_one_five*(C_V(cell,subthread_five)-C_V(cell,subthread_one));
			F_D_two_y=C_Dip_one_two*(C_V(cell,subthread_one)-C_V(cell,subthread_two))+C_Dip_two_three*(C_V(cell,subthread_three)-C_V(cell,subthread_two))+C_Dip_two_four*(C_V(cell,subthread_four)-C_V(cell,subthread_two))+C_Dip_two_five*(C_V(cell,subthread_five)-C_V(cell,subthread_two));
			F_D_three_y=C_Dip_one_three*(C_V(cell,subthread_one)-C_V(cell,subthread_three))+C_Dip_two_three*(C_V(cell,subthread_two)-C_V(cell,subthread_three))+C_Dip_three_four*(C_V(cell,subthread_four)-C_V(cell,subthread_three))+C_Dip_three_five*(C_V(cell,subthread_five)-C_V(cell,subthread_three));
			F_D_four_y=C_Dip_one_four*(C_V(cell,subthread_one)-C_V(cell,subthread_four))+C_Dip_two_four*(C_V(cell,subthread_two)-C_V(cell,subthread_four))+C_Dip_three_four*(C_V(cell,subthread_three)-C_V(cell,subthread_four))+C_Dip_four_five*(C_V(cell,subthread_five)-C_V(cell,subthread_four));
			F_D_five_y=C_Dip_one_five*(C_V(cell,subthread_one)-C_V(cell,subthread_five))+C_Dip_two_five*(C_V(cell,subthread_two)-C_V(cell,subthread_five))+C_Dip_three_five*(C_V(cell,subthread_three)-C_V(cell,subthread_five))+C_Dip_four_five*(C_V(cell,subthread_four)-C_V(cell,subthread_five));

			F_D_one_z=C_Dip_one_two*(C_W(cell,subthread_two)-C_W(cell,subthread_one))+C_Dip_one_three*(C_W(cell,subthread_three)-C_W(cell,subthread_one))+C_Dip_one_four*(C_W(cell,subthread_four)-C_W(cell,subthread_one))+C_Dip_one_five*(C_W(cell,subthread_five)-C_W(cell,subthread_one));
			F_D_two_z=C_Dip_one_two*(C_W(cell,subthread_one)-C_W(cell,subthread_two))+C_Dip_two_three*(C_W(cell,subthread_three)-C_W(cell,subthread_two))+C_Dip_two_four*(C_W(cell,subthread_four)-C_W(cell,subthread_two))+C_Dip_two_five*(C_W(cell,subthread_five)-C_W(cell,subthread_two));
			F_D_three_z=C_Dip_one_three*(C_W(cell,subthread_one)-C_W(cell,subthread_three))+C_Dip_two_three*(C_W(cell,subthread_two)-C_W(cell,subthread_three))+C_Dip_three_four*(C_W(cell,subthread_four)-C_W(cell,subthread_three))+C_Dip_three_five*(C_W(cell,subthread_five)-C_W(cell,subthread_three));
			F_D_four_z=C_Dip_one_four*(C_W(cell,subthread_one)-C_W(cell,subthread_four))+C_Dip_two_four*(C_W(cell,subthread_two)-C_W(cell,subthread_four))+C_Dip_three_four*(C_W(cell,subthread_three)-C_W(cell,subthread_four))+C_Dip_four_five*(C_W(cell,subthread_five)-C_W(cell,subthread_four));
			F_D_five_z=C_Dip_one_five*(C_W(cell,subthread_one)-C_W(cell,subthread_five))+C_Dip_two_five*(C_W(cell,subthread_two)-C_W(cell,subthread_five))+C_Dip_three_five*(C_W(cell,subthread_three)-C_W(cell,subthread_five))+C_Dip_four_five*(C_W(cell,subthread_four)-C_W(cell,subthread_five));
			
			Lun_one=4.*(1.-corinp*corinp)*(2.-C_VOF(cell,subthread_one))*rhop*C_VOF(cell,subthread_one)*C_VOF(cell,subthread_one)*C_GT(cell,subthread_one)*sqrt(C_GT(cell,subthread_one)/PI)/(d_one*(1.-C_VOF(cell,subthread_one))*(1.-C_VOF(cell,subthread_one))*(1.-C_VOF(cell,subthread_one)));
			Lun_two=4.*(1.-corinp*corinp)*(2.-C_VOF(cell,subthread_two))*rhop*C_VOF(cell,subthread_two)*C_VOF(cell,subthread_two)*C_GT(cell,subthread_two)*sqrt(C_GT(cell,subthread_two)/PI)/(d_two*(1.-C_VOF(cell,subthread_two))*(1.-C_VOF(cell,subthread_two))*(1.-C_VOF(cell,subthread_two)));
			Lun_three=4.*(1.-corinp*corinp)*(2.-C_VOF(cell,subthread_three))*rhop*C_VOF(cell,subthread_three)*C_VOF(cell,subthread_three)*C_GT(cell,subthread_three)*sqrt(C_GT(cell,subthread_three)/PI)/(d_three*(1.-C_VOF(cell,subthread_three))*(1.-C_VOF(cell,subthread_three))*(1.-C_VOF(cell,subthread_three)));
			Lun_four=4.*(1.-corinp*corinp)*(2.-C_VOF(cell,subthread_four))*rhop*C_VOF(cell,subthread_four)*C_VOF(cell,subthread_four)*C_GT(cell,subthread_four)*sqrt(C_GT(cell,subthread_four)/PI)/(d_four*(1.-C_VOF(cell,subthread_four))*(1.-C_VOF(cell,subthread_four))*(1.-C_VOF(cell,subthread_four)));
			Lun_five=4.*(1.-corinp*corinp)*(2.-C_VOF(cell,subthread_five))*rhop*C_VOF(cell,subthread_five)*C_VOF(cell,subthread_five)*C_GT(cell,subthread_five)*sqrt(C_GT(cell,subthread_five)/PI)/(d_five*(1.-C_VOF(cell,subthread_five))*(1.-C_VOF(cell,subthread_five))*(1.-C_VOF(cell,subthread_five)));

			Gen_one=C_U(cell,subthread_one)*F_D_one_x+C_V(cell,subthread_one)*F_D_one_y+C_W(cell,subthread_one)*F_D_one_z;
			Gen_two=C_U(cell,subthread_two)*F_D_two_x+C_V(cell,subthread_two)*F_D_two_y+C_W(cell,subthread_two)*F_D_two_z;
			Gen_three=C_U(cell,subthread_three)*F_D_three_x+C_V(cell,subthread_three)*F_D_three_y+C_W(cell,subthread_three)*F_D_three_z;
			Gen_four=C_U(cell,subthread_four)*F_D_four_x+C_V(cell,subthread_four)*F_D_four_y+C_W(cell,subthread_four)*F_D_four_z;
			Gen_five=C_U(cell,subthread_five)*F_D_five_x+C_V(cell,subthread_five)*F_D_five_y+C_W(cell,subthread_five)*F_D_five_z;

			mu_one=pow((d_one+d_one)/2.,3.)/48.*g_one_one*m_one*m_one/(m_one+m_one)*pow((m_one*m_one/(theta_one*theta_one)),1.5)*n_one*n_one*(1+e_one_one)*sqrt(PI)*d_one*m_one*m_one/(m_one+m_one)/3.*6./5.*2./theta_one*R_one_one_one;
			mu_two=pow((d_two+d_two)/2.,3.)/48.*g_two_two*m_two*m_two/(m_two+m_two)*pow((m_two*m_two/(theta_two*theta_two)),1.5)*n_two*n_two*(1+e_two_two)*sqrt(PI)*d_two*m_two*m_two/(m_two+m_two)/3.*6./5.*2./theta_two*R_one_two_two;
			mu_three=pow((d_three+d_three)/2.,3.)/48.*g_three_three*m_three*m_three/(m_three+m_three)*pow((m_three*m_three/(theta_three*theta_three)),1.5)*n_three*n_three*(1+e_three_three)*sqrt(PI)*d_three*m_three*m_three/(m_three+m_three)/3.*6./5.*2./theta_three*R_one_three_three;
			mu_four=pow((d_four+d_four)/2.,3.)/48.*g_four_four*m_four*m_four/(m_four+m_four)*pow((m_four*m_four/(theta_four*theta_four)),1.5)*n_four*n_four*(1+e_four_four)*sqrt(PI)*d_four*m_four*m_four/(m_four+m_four)/3.*6./5.*2./theta_four*R_one_four_four;
			mu_five=pow((d_five+d_five)/2.,3.)/48.*g_five_five*m_five*m_five/(m_five+m_five)*pow((m_five*m_five/(theta_five*theta_five)),1.5)*n_five*n_five*(1+e_five_five)*sqrt(PI)*d_five*m_five*m_five/(m_five+m_five)/3.*6./5.*2./theta_five*R_one_five_five;

			lamda_one=pow((d_one+d_one)/2.,3.)/48.*g_one_one*m_one*m_one/(m_one+m_one)*pow((m_one*m_one/(theta_one*theta_one)),1.5)*n_one*n_one*(1+e_one_one)*sqrt(PI)*d_one*m_one*m_one/(m_one+m_one)/3.*2./theta_one*R_one_one_one+2./3.*mu_one;
			lamda_two=pow((d_two+d_two)/2.,3.)/48.*g_two_two*m_two*m_two/(m_two+m_two)*pow((m_two*m_two/(theta_two*theta_two)),1.5)*n_two*n_two*(1+e_two_two)*sqrt(PI)*d_two*m_two*m_two/(m_two+m_two)/3.*2./theta_two*R_one_two_two+2./3.*mu_two;
			lamda_three=pow((d_three+d_three)/2.,3.)/48.*g_three_three*m_three*m_three/(m_three+m_three)*pow((m_three*m_three/(theta_three*theta_three)),1.5)*n_three*n_three*(1+e_three_three)*sqrt(PI)*d_three*m_three*m_three/(m_three+m_three)/3.*2./theta_three*R_one_three_three+2./3.*mu_three;
			lamda_four=pow((d_four+d_four)/2.,3.)/48.*g_four_four*m_four*m_four/(m_four+m_four)*pow((m_four*m_four/(theta_four*theta_four)),1.5)*n_four*n_four*(1+e_four_four)*sqrt(PI)*d_four*m_four*m_four/(m_four+m_four)/3.*2./theta_four*R_one_four_four+2./3.*mu_four;
			lamda_five=pow((d_five+d_five)/2.,3.)/48.*g_five_five*m_five*m_five/(m_five+m_five)*pow((m_five*m_five/(theta_five*theta_five)),1.5)*n_five*n_five*(1+e_five_five)*sqrt(PI)*d_five*m_five*m_five/(m_five+m_five)/3.*2./theta_five*R_one_five_five+2./3.*mu_five;

			Freq_one_one=2.*g_one_one*pow(d_one_one,2.)*n_one*n_one*sqrt(PI*SS_one_one);
			Freq_one_two=2.*g_one_two*pow(d_one_two,2.)*n_one*n_two*sqrt(PI*SS_one_two);
			Freq_one_three=2.*g_one_three*pow(d_one_three,2.)*n_one*n_three*sqrt(PI*SS_one_three);
			Freq_one_four=2.*g_one_four*pow(d_one_four,2.)*n_one*n_four*sqrt(PI*SS_one_four);
			Freq_one_five=2.*g_one_five*pow(d_one_five,2.)*n_one*n_five*sqrt(PI*SS_one_five);

			Freq_two_two=2.*g_two_two*pow(d_two_two,2.)*n_two*n_two*sqrt(PI*SS_two_two);
			Freq_two_three=2.*g_two_three*pow(d_two_three,2.)*n_two*n_three*sqrt(PI*SS_two_three);
			Freq_two_four=2.*g_two_four*pow(d_two_four,2.)*n_two*n_four*sqrt(PI*SS_two_four);
			Freq_two_five=2.*g_two_five*pow(d_two_five,2.)*n_two*n_five*sqrt(PI*SS_two_five);

			Freq_three_three=2.*g_three_three*pow(d_three_three,2.)*n_three*n_three*sqrt(PI*SS_three_three);
			Freq_three_four=2.*g_three_four*pow(d_three_four,2.)*n_three*n_four*sqrt(PI*SS_three_four);
			Freq_three_five=2.*g_three_five*pow(d_three_five,2.)*n_three*n_five*sqrt(PI*SS_three_five);

			Freq_four_four=2.*g_four_four*pow(d_four_four,2.)*n_four*n_four*sqrt(PI*SS_four_four);
			Freq_four_five=2.*g_four_five*pow(d_four_five,2.)*n_four*n_five*sqrt(PI*SS_four_five);

			Freq_five_five=2.*g_five_five*pow(d_five_five,2.)*n_five*n_five*sqrt(PI*SS_five_five);

			M_rate_one=m_one*(-2.*Freq_one_one*Sagg_one_one-Freq_one_two*Sagg_one_two-Freq_one_three*Sagg_one_three-Freq_one_four*Sagg_one_four+2.*Freq_one_two*Sbrk_one_two+3.*Freq_one_three*Sbrk_one_three+4.*Freq_one_four*Sbrk_one_four+5.*Freq_one_five*Sbrk_one_five+4.*Freq_two_two*Sbrk_two_two+5.*Freq_two_three*Sbrk_two_three+6.*Freq_two_four*Sbrk_two_four+7.*Freq_two_five*Sbrk_two_five+6.*Freq_three_three*Sbrk_three_three+7.*Freq_three_four*Sbrk_three_four+8.*Freq_three_five*Sbrk_three_five+8.*Freq_four_four*Sbrk_four_four+9.*Freq_four_five*Sbrk_four_five+10.*Freq_five_five*Sbrk_five_five);
			M_rate_two=m_two*(Freq_one_one*Sagg_one_one-Freq_one_two*Sagg_one_two-2.*Freq_two_two*Sagg_two_two-Freq_two_three*Sagg_two_three-Freq_one_two*Sbrk_one_two-2.*Freq_two_two*Sbrk_two_two-Freq_two_three*Sbrk_two_three-Freq_two_four*Sbrk_two_four-Freq_two_five*Sbrk_two_five);
			M_rate_three=m_three*(Freq_one_two*Sagg_one_two-Freq_one_three*Sagg_one_three-Freq_two_three*Sagg_two_three-Freq_one_three*Sbrk_one_three-Freq_two_three*Sbrk_two_three-2.*Freq_three_three*Sbrk_three_three-Freq_three_four*Sbrk_three_four-Freq_three_five*Sbrk_three_five);
			M_rate_four=m_four*(Freq_one_three*Sagg_one_three+Freq_two_two*Sagg_two_two-Freq_one_four*Sagg_one_four-Freq_one_four*Sbrk_one_four-Freq_two_four*Sbrk_two_four-Freq_three_four*Sbrk_three_four-2.*Freq_four_four*Sbrk_four_four-Freq_four_five*Sbrk_four_five);
			M_rate_five=m_five*(Freq_one_four*Sagg_one_four+Freq_two_three*Sagg_two_three-Freq_one_five*Sbrk_one_five-Freq_two_five*Sbrk_two_five-Freq_three_five*Sbrk_three_five-Freq_four_five*Sbrk_four_five-2.*Freq_five_five*Sbrk_five_five);

			Mom_rate_one_x=m_one*(-2.*Freq_one_one*Sagg_one_one*C_U(cell,subthread_one)-Freq_one_two*Sagg_one_two*C_U(cell,subthread_one)-Freq_one_three*Sagg_one_three*C_U(cell,subthread_one)-Freq_one_four*Sagg_one_four*C_U(cell,subthread_one)+2.*Freq_one_two*Sbrk_one_two*C_U(cell,subthread_two)+3.*Freq_one_three*Sbrk_one_three*C_U(cell,subthread_three)+4.*Freq_one_four*Sbrk_one_four*C_U(cell,subthread_four)+5.*Freq_one_five*Sbrk_one_five*C_U(cell,subthread_five)+4.*Freq_two_two*Sbrk_two_two*C_U(cell,subthread_two)+5.*Freq_two_three*Sbrk_two_three*(2.*C_U(cell,subthread_two)+3.*C_U(cell,subthread_three))/5.+6.*Freq_two_four*Sbrk_two_four*(2.*C_U(cell,subthread_two)+4.*C_U(cell,subthread_four))/6.+7.*Freq_two_five*Sbrk_two_five*(2.*C_U(cell,subthread_two)+5.*C_U(cell,subthread_five))/7.+6.*Freq_three_three*Sbrk_three_three*(3.*C_U(cell,subthread_three)+3.*C_U(cell,subthread_three))/6.+7.*Freq_three_four*Sbrk_three_four*(3.*C_U(cell,subthread_three)+4.*C_U(cell,subthread_four))/7.+8.*Freq_three_five*Sbrk_three_five*(3.*C_U(cell,subthread_three)+5.*C_U(cell,subthread_five))/8.+8.*Freq_four_four*Sbrk_four_four*(4.*C_U(cell,subthread_four)+4.*C_U(cell,subthread_four))/8.+9.*Freq_four_five*Sbrk_four_five*(4.*C_U(cell,subthread_four)+5.*C_U(cell,subthread_five))/9.+10.*Freq_five_five*Sbrk_five_five*(5.*C_U(cell,subthread_five)+5.*C_U(cell,subthread_five))/10.);
			Mom_rate_two_x=m_two*(Freq_one_one*Sagg_one_one*C_U(cell,subthread_one)-Freq_one_two*Sagg_one_two*C_U(cell,subthread_two)-2.*Freq_two_two*Sagg_two_two*C_U(cell,subthread_two)-Freq_two_three*Sagg_two_three*C_U(cell,subthread_two)-Freq_one_two*Sbrk_one_two*C_U(cell,subthread_two)-2.*Freq_two_two*Sbrk_two_two*C_U(cell,subthread_two)-Freq_two_three*Sbrk_two_three*C_U(cell,subthread_two)-Freq_two_four*Sbrk_two_four*C_U(cell,subthread_two)-Freq_two_five*Sbrk_two_five*C_U(cell,subthread_two));
			Mom_rate_three_x=m_three*(Freq_one_two*Sagg_one_two*(1.*C_U(cell,subthread_one)+2.*C_U(cell,subthread_two))/3.-Freq_one_three*Sagg_one_three*C_U(cell,subthread_three)-Freq_two_three*Sagg_two_three*C_U(cell,subthread_three)-Freq_one_three*Sbrk_one_three*C_U(cell,subthread_three)-Freq_two_three*Sbrk_two_three*C_U(cell,subthread_three)-2.*Freq_three_three*Sbrk_three_three*C_U(cell,subthread_three)-Freq_three_four*Sbrk_three_four*C_U(cell,subthread_three)-Freq_three_five*Sbrk_three_five*C_U(cell,subthread_three));
			Mom_rate_four_x=m_four*(Freq_one_three*Sagg_one_three*(1.*C_U(cell,subthread_one)+3.*C_U(cell,subthread_three))/4.+Freq_two_two*Sagg_two_two*(2.*C_U(cell,subthread_two)+2.*C_U(cell,subthread_two))/4.-Freq_one_four*Sagg_one_four*C_U(cell,subthread_four)-Freq_one_four*Sbrk_one_four*C_U(cell,subthread_four)-Freq_two_four*Sbrk_two_four*C_U(cell,subthread_four)-Freq_three_four*Sbrk_three_four*C_U(cell,subthread_four)-2.*Freq_four_four*Sbrk_four_four*C_U(cell,subthread_four)-Freq_four_five*Sbrk_four_five*C_U(cell,subthread_four));
			Mom_rate_five_x=m_five*(Freq_one_four*Sagg_one_four*(1.*C_U(cell,subthread_one)+4.*C_U(cell,subthread_four))/5.+Freq_two_three*Sagg_two_three*(2.*C_U(cell,subthread_two)+3.*C_U(cell,subthread_three))/5.-Freq_one_five*Sbrk_one_five*C_U(cell,subthread_five)-Freq_two_five*Sbrk_two_five*C_U(cell,subthread_five)-Freq_three_five*Sbrk_three_five*C_U(cell,subthread_five)-Freq_four_five*Sbrk_four_five*C_U(cell,subthread_five)-2.*Freq_five_five*Sbrk_five_five*C_U(cell,subthread_five));

			Mom_rate_one_y=m_one*(-2.*Freq_one_one*Sagg_one_one*C_V(cell,subthread_one)-Freq_one_two*Sagg_one_two*C_V(cell,subthread_one)-Freq_one_three*Sagg_one_three*C_V(cell,subthread_one)-Freq_one_four*Sagg_one_four*C_V(cell,subthread_one)+2.*Freq_one_two*Sbrk_one_two*C_V(cell,subthread_two)+3.*Freq_one_three*Sbrk_one_three*C_V(cell,subthread_three)+4.*Freq_one_four*Sbrk_one_four*C_V(cell,subthread_four)+5.*Freq_one_five*Sbrk_one_five*C_V(cell,subthread_five)+4.*Freq_two_two*Sbrk_two_two*C_V(cell,subthread_two)+5.*Freq_two_three*Sbrk_two_three*(2.*C_V(cell,subthread_two)+3.*C_V(cell,subthread_three))/5.+6.*Freq_two_four*Sbrk_two_four*(2.*C_V(cell,subthread_two)+4.*C_V(cell,subthread_four))/6.+7.*Freq_two_five*Sbrk_two_five*(2.*C_V(cell,subthread_two)+5.*C_V(cell,subthread_five))/7.+6.*Freq_three_three*Sbrk_three_three*(3.*C_V(cell,subthread_three)+3.*C_V(cell,subthread_three))/6.+7.*Freq_three_four*Sbrk_three_four*(3.*C_V(cell,subthread_three)+4.*C_V(cell,subthread_four))/7.+8.*Freq_three_five*Sbrk_three_five*(3.*C_V(cell,subthread_three)+5.*C_V(cell,subthread_five))/8.+8.*Freq_four_four*Sbrk_four_four*(4.*C_V(cell,subthread_four)+4.*C_V(cell,subthread_four))/8.+9.*Freq_four_five*Sbrk_four_five*(4.*C_V(cell,subthread_four)+5.*C_V(cell,subthread_five))/9.+10.*Freq_five_five*Sbrk_five_five*(5.*C_V(cell,subthread_five)+5.*C_V(cell,subthread_five))/10.);
			Mom_rate_two_y=m_two*(Freq_one_one*Sagg_one_one*C_V(cell,subthread_one)-Freq_one_two*Sagg_one_two*C_V(cell,subthread_two)-2.*Freq_two_two*Sagg_two_two*C_V(cell,subthread_two)-Freq_two_three*Sagg_two_three*C_V(cell,subthread_two)-Freq_one_two*Sbrk_one_two*C_V(cell,subthread_two)-2.*Freq_two_two*Sbrk_two_two*C_V(cell,subthread_two)-Freq_two_three*Sbrk_two_three*C_V(cell,subthread_two)-Freq_two_four*Sbrk_two_four*C_V(cell,subthread_two)-Freq_two_five*Sbrk_two_five*C_V(cell,subthread_two));
			Mom_rate_three_y=m_three*(Freq_one_two*Sagg_one_two*(1.*C_V(cell,subthread_one)+2.*C_V(cell,subthread_two))/3.-Freq_one_three*Sagg_one_three*C_V(cell,subthread_three)-Freq_two_three*Sagg_two_three*C_V(cell,subthread_three)-Freq_one_three*Sbrk_one_three*C_V(cell,subthread_three)-Freq_two_three*Sbrk_two_three*C_V(cell,subthread_three)-2.*Freq_three_three*Sbrk_three_three*C_V(cell,subthread_three)-Freq_three_four*Sbrk_three_four*C_V(cell,subthread_three)-Freq_three_five*Sbrk_three_five*C_V(cell,subthread_three));
			Mom_rate_four_y=m_four*(Freq_one_three*Sagg_one_three*(1.*C_V(cell,subthread_one)+3.*C_V(cell,subthread_three))/4.+Freq_two_two*Sagg_two_two*(2.*C_V(cell,subthread_two)+2.*C_V(cell,subthread_two))/4.-Freq_one_four*Sagg_one_four*C_V(cell,subthread_four)-Freq_one_four*Sbrk_one_four*C_V(cell,subthread_four)-Freq_two_four*Sbrk_two_four*C_V(cell,subthread_four)-Freq_three_four*Sbrk_three_four*C_V(cell,subthread_four)-2.*Freq_four_four*Sbrk_four_four*C_V(cell,subthread_four)-Freq_four_five*Sbrk_four_five*C_V(cell,subthread_four));
			Mom_rate_five_y=m_five*(Freq_one_four*Sagg_one_four*(1.*C_V(cell,subthread_one)+4.*C_V(cell,subthread_four))/5.+Freq_two_three*Sagg_two_three*(2.*C_V(cell,subthread_two)+3.*C_V(cell,subthread_three))/5.-Freq_one_five*Sbrk_one_five*C_V(cell,subthread_five)-Freq_two_five*Sbrk_two_five*C_V(cell,subthread_five)-Freq_three_five*Sbrk_three_five*C_V(cell,subthread_five)-Freq_four_five*Sbrk_four_five*C_V(cell,subthread_five)-2.*Freq_five_five*Sbrk_five_five*C_V(cell,subthread_five));

			Mom_rate_one_z=m_one*(-2.*Freq_one_one*Sagg_one_one*C_W(cell,subthread_one)-Freq_one_two*Sagg_one_two*C_W(cell,subthread_one)-Freq_one_three*Sagg_one_three*C_W(cell,subthread_one)-Freq_one_four*Sagg_one_four*C_W(cell,subthread_one)+2.*Freq_one_two*Sbrk_one_two*C_W(cell,subthread_two)+3.*Freq_one_three*Sbrk_one_three*C_W(cell,subthread_three)+4.*Freq_one_four*Sbrk_one_four*C_W(cell,subthread_four)+5.*Freq_one_five*Sbrk_one_five*C_W(cell,subthread_five)+4.*Freq_two_two*Sbrk_two_two*C_W(cell,subthread_two)+5.*Freq_two_three*Sbrk_two_three*(2.*C_W(cell,subthread_two)+3.*C_W(cell,subthread_three))/5.+6.*Freq_two_four*Sbrk_two_four*(2.*C_W(cell,subthread_two)+4.*C_W(cell,subthread_four))/6.+7.*Freq_two_five*Sbrk_two_five*(2.*C_W(cell,subthread_two)+5.*C_W(cell,subthread_five))/7.+6.*Freq_three_three*Sbrk_three_three*(3.*C_W(cell,subthread_three)+3.*C_W(cell,subthread_three))/6.+7.*Freq_three_four*Sbrk_three_four*(3.*C_W(cell,subthread_three)+4.*C_W(cell,subthread_four))/7.+8.*Freq_three_five*Sbrk_three_five*(3.*C_W(cell,subthread_three)+5.*C_W(cell,subthread_five))/8.+8.*Freq_four_four*Sbrk_four_four*(4.*C_W(cell,subthread_four)+4.*C_W(cell,subthread_four))/8.+9.*Freq_four_five*Sbrk_four_five*(4.*C_W(cell,subthread_four)+5.*C_W(cell,subthread_five))/9.+10.*Freq_five_five*Sbrk_five_five*(5.*C_W(cell,subthread_five)+5.*C_W(cell,subthread_five))/10);
			Mom_rate_two_z=m_two*(Freq_one_one*Sagg_one_one*C_W(cell,subthread_one)-Freq_one_two*Sagg_one_two*C_W(cell,subthread_two)-2.*Freq_two_two*Sagg_two_two*C_W(cell,subthread_two)-Freq_two_three*Sagg_two_three*C_W(cell,subthread_two)-Freq_one_two*Sbrk_one_two*C_W(cell,subthread_two)-2.*Freq_two_two*Sbrk_two_two*C_W(cell,subthread_two)-Freq_two_three*Sbrk_two_three*C_W(cell,subthread_two)-Freq_two_four*Sbrk_two_four*C_W(cell,subthread_two)-Freq_two_five*Sbrk_two_five*C_W(cell,subthread_two));
			Mom_rate_three_z=m_three*(Freq_one_two*Sagg_one_two*(1.*C_W(cell,subthread_one)+2.*C_W(cell,subthread_two))/3.-Freq_one_three*Sagg_one_three*C_W(cell,subthread_three)-Freq_two_three*Sagg_two_three*C_W(cell,subthread_three)-Freq_one_three*Sbrk_one_three*C_W(cell,subthread_three)-Freq_two_three*Sbrk_two_three*C_W(cell,subthread_three)-2.*Freq_three_three*Sbrk_three_three*C_W(cell,subthread_three)-Freq_three_four*Sbrk_three_four*C_W(cell,subthread_three)-Freq_three_five*Sbrk_three_five*C_W(cell,subthread_three));
			Mom_rate_four_z=m_four*(Freq_one_three*Sagg_one_three*(1.*C_W(cell,subthread_one)+3.*C_W(cell,subthread_three))/4.+Freq_two_two*Sagg_two_two*(2.*C_W(cell,subthread_two)+2.*C_W(cell,subthread_two))/4.-Freq_one_four*Sagg_one_four*C_W(cell,subthread_four)-Freq_one_four*Sbrk_one_four*C_W(cell,subthread_four)-Freq_two_four*Sbrk_two_four*C_W(cell,subthread_four)-Freq_three_four*Sbrk_three_four*C_W(cell,subthread_four)-2.*Freq_four_four*Sbrk_four_four*C_W(cell,subthread_four)-Freq_four_five*Sbrk_four_five*C_W(cell,subthread_four));
			Mom_rate_five_z=m_five*(Freq_one_four*Sagg_one_four*(1.*C_W(cell,subthread_one)+4.*C_W(cell,subthread_four))/5.+Freq_two_three*Sagg_two_three*(2.*C_W(cell,subthread_two)+3.*C_W(cell,subthread_three))/5.-Freq_one_five*Sbrk_one_five*C_W(cell,subthread_five)-Freq_two_five*Sbrk_two_five*C_W(cell,subthread_five)-Freq_three_five*Sbrk_three_five*C_W(cell,subthread_five)-Freq_four_five*Sbrk_four_five*C_W(cell,subthread_five)-2.*Freq_five_five*Sbrk_five_five*C_W(cell,subthread_five));
						
			C_UDMI(cell,thread,0)=e_one_one;
			C_UDMI(cell,thread,1)=e_one_two;
			C_UDMI(cell,thread,2)=e_one_three;
			C_UDMI(cell,thread,3)=e_one_four;
			C_UDMI(cell,thread,4)=e_one_five;

			C_UDMI(cell,thread,5)=e_two_two;
			C_UDMI(cell,thread,6)=e_two_three;
			C_UDMI(cell,thread,7)=e_two_four;
			C_UDMI(cell,thread,8)=e_two_five;

			C_UDMI(cell,thread,9)=e_three_three;
			C_UDMI(cell,thread,10)=e_three_four;
			C_UDMI(cell,thread,11)=e_three_five;

			C_UDMI(cell,thread,12)=e_four_four;
			C_UDMI(cell,thread,13)=e_four_five;

			C_UDMI(cell,thread,14)=e_five_five;

			C_UDMI(cell,thread,15)=N_one+Lun_one+Gen_one;
			C_UDMI(cell,thread,16)=N_two+Lun_two+Gen_two;
			C_UDMI(cell,thread,17)=N_three+Lun_three+Gen_three;
			C_UDMI(cell,thread,18)=N_four+Lun_four+Gen_four;
			C_UDMI(cell,thread,19)=N_five+Lun_five+Gen_five;

			C_UDMI(cell,thread,20)=P_one;
			C_UDMI(cell,thread,21)=P_two;
			C_UDMI(cell,thread,22)=P_three;
			C_UDMI(cell,thread,23)=P_four;
			C_UDMI(cell,thread,24)=P_five;

			C_UDMI(cell,thread,25)=C_Dip_one_two;
			C_UDMI(cell,thread,26)=C_Dip_one_three;
			C_UDMI(cell,thread,27)=C_Dip_one_four;
			C_UDMI(cell,thread,28)=C_Dip_one_five;

			C_UDMI(cell,thread,29)=C_Dip_two_three;
			C_UDMI(cell,thread,30)=C_Dip_two_four;
			C_UDMI(cell,thread,31)=C_Dip_two_five;

			C_UDMI(cell,thread,32)=C_Dip_three_four;
			C_UDMI(cell,thread,33)=C_Dip_three_five;

			C_UDMI(cell,thread,34)=C_Dip_four_five;
			
			C_UDMI(cell,thread,35)=mu_one;
			C_UDMI(cell,thread,36)=mu_two;
			C_UDMI(cell,thread,37)=mu_three;
			C_UDMI(cell,thread,38)=mu_four;
			C_UDMI(cell,thread,39)=mu_five;

			C_UDMI(cell,thread,40)=k_one;
			C_UDMI(cell,thread,41)=k_two;
			C_UDMI(cell,thread,42)=k_three;
			C_UDMI(cell,thread,43)=k_four;
			C_UDMI(cell,thread,44)=k_five;

			C_UDMI(cell,thread,45)=lamda_one;
			C_UDMI(cell,thread,46)=lamda_two;
			C_UDMI(cell,thread,47)=lamda_three;
			C_UDMI(cell,thread,48)=lamda_four;
			C_UDMI(cell,thread,49)=lamda_five;
			
			C_UDMI(cell,thread,50)=C_VOF(cell,subthread_one)+C_VOF(cell,subthread_two)+C_VOF(cell,subthread_three)+C_VOF(cell,subthread_four)+C_VOF(cell,subthread_five);
			
			C_UDMI(cell,thread,51)=M_rate_one;
			C_UDMI(cell,thread,52)=M_rate_two;
			C_UDMI(cell,thread,53)=M_rate_three;
			C_UDMI(cell,thread,54)=M_rate_four;
			C_UDMI(cell,thread,55)=M_rate_five;

			C_UDMI(cell,thread,56)=Mom_rate_one_x;
			C_UDMI(cell,thread,57)=Mom_rate_one_y;
			C_UDMI(cell,thread,58)=Mom_rate_one_z;
			C_UDMI(cell,thread,59)=Mom_rate_two_x;
			C_UDMI(cell,thread,60)=Mom_rate_two_y;
			C_UDMI(cell,thread,61)=Mom_rate_two_z;
			C_UDMI(cell,thread,62)=Mom_rate_three_x;
			C_UDMI(cell,thread,63)=Mom_rate_three_y;
			C_UDMI(cell,thread,64)=Mom_rate_three_z;
			C_UDMI(cell,thread,65)=Mom_rate_four_x;
			C_UDMI(cell,thread,66)=Mom_rate_four_y;
			C_UDMI(cell,thread,67)=Mom_rate_four_z;
			C_UDMI(cell,thread,68)=Mom_rate_five_x;
			C_UDMI(cell,thread,69)=Mom_rate_five_y;
			C_UDMI(cell,thread,70)=Mom_rate_five_z;

			}
		end_c_loop(cell,thread)
		}
}

/*Iddir and Arastoopour 2005 shear viscosity*/
DEFINE_PROPERTY(GranularShearViscosityOne, cell, thread)
{
	real shearviscosity;
	shearviscosity=C_UDMI(cell,thread,35)/C_VOF(cell,thread);
	return shearviscosity;
}
DEFINE_PROPERTY(GranularShearViscosityTwo, cell, thread)
{
	real shearviscosity;
	shearviscosity=C_UDMI(cell,thread,36)/C_VOF(cell,thread);
	return shearviscosity;
}
DEFINE_PROPERTY(GranularShearViscosityThree, cell, thread)
{
	real shearviscosity;
	shearviscosity=C_UDMI(cell,thread,37)/C_VOF(cell,thread);
	return shearviscosity;
}
DEFINE_PROPERTY(GranularShearViscosityFour, cell, thread)
{
	real shearviscosity;
	shearviscosity=C_UDMI(cell,thread,38)/C_VOF(cell,thread);
	return shearviscosity;
}
DEFINE_PROPERTY(GranularShearViscosityFive, cell, thread)
{
	real shearviscosity;
	shearviscosity=C_UDMI(cell,thread,39)/C_VOF(cell,thread);
	return shearviscosity;
}
	
/*Iddir and Arastoopour 2005 bulk viscosity*/
DEFINE_PROPERTY(GranularBulkViscosityOne, cell, thread)
{
	real bulkviscosity;
	bulkviscosity=C_UDMI(cell,thread,45);
	return bulkviscosity;
}	
DEFINE_PROPERTY(GranularBulkViscosityTwo, cell, thread)
{
	real bulkviscosity;
	bulkviscosity=C_UDMI(cell,thread,46);
	return bulkviscosity;
}
DEFINE_PROPERTY(GranularBulkViscosityThree, cell, thread)
{
	real bulkviscosity;
	bulkviscosity=C_UDMI(cell,thread,47);
	return bulkviscosity;
}
DEFINE_PROPERTY(GranularBulkViscosityFour, cell, thread)
{
	real bulkviscosity;
	bulkviscosity=C_UDMI(cell,thread,48);
	return bulkviscosity;
}
DEFINE_PROPERTY(GranularBulkViscosityFive, cell, thread)
{
	real bulkviscosity;
	bulkviscosity=C_UDMI(cell,thread,49);
	return bulkviscosity;
}

/*Iddir and Arastoopour 2005 granular pressure*/
DEFINE_PROPERTY(GranularPressureOne, cell, thread)
{
	real Ps;
	Ps=C_UDMI(cell,thread,20);
	return Ps;
}
DEFINE_PROPERTY(GranularPressureTwo, cell, thread)
{
	real Ps;
	Ps=C_UDMI(cell,thread,21);
	return Ps;
}
DEFINE_PROPERTY(GranularPressureThree, cell, thread)
{
	real Ps;
	Ps=C_UDMI(cell,thread,22);
	return Ps;
}
DEFINE_PROPERTY(GranularPressureFour, cell, thread)
{
	real Ps;
	Ps=C_UDMI(cell,thread,23);
	return Ps;
}
DEFINE_PROPERTY(GranularPressureFive, cell, thread)
{
	real Ps;
	Ps=C_UDMI(cell,thread,24);
	return Ps;
}

/*Iddir and Arastoopour 2005 conductivity*/	
DEFINE_PROPERTY(GranularConductivityOne, cell, thread)
{
	real kappa;
	kappa=C_UDMI(cell,thread,40);
	return kappa;
}
DEFINE_PROPERTY(GranularConductivityTwo, cell, thread)
{
	real kappa;
	kappa=C_UDMI(cell,thread,41);
	return kappa;
}
DEFINE_PROPERTY(GranularConductivityThree, cell, thread)
{
	real kappa;
	kappa=C_UDMI(cell,thread,42);
	return kappa;
}
DEFINE_PROPERTY(GranularConductivityFour, cell, thread)
{
	real kappa;
	kappa=C_UDMI(cell,thread,43);
	return kappa;
}
DEFINE_PROPERTY(GranularConductivityFive, cell, thread)
{
	real kappa;
	kappa=C_UDMI(cell,thread,44);
	return kappa;
}

/*Iddir and Arastoopour 2005 dissipation rate*/
DEFINE_SOURCE(GranularDissipationOne, cell, thread, dS, eqn)
{
	real CoolingRate;
	CoolingRate = C_UDMI(cell,thread,15);
	return CoolingRate;
}
DEFINE_SOURCE(GranularDissipationTwo, cell, thread, dS, eqn)
{
	real CoolingRate;
	CoolingRate = C_UDMI(cell,thread,16);
	return CoolingRate;
}
DEFINE_SOURCE(GranularDissipationThree, cell, thread, dS, eqn)
{
	real CoolingRate;
	CoolingRate = C_UDMI(cell,thread,17);
	return CoolingRate;
}
DEFINE_SOURCE(GranularDissipationFour, cell, thread, dS, eqn)
{
	real CoolingRate;
	CoolingRate = C_UDMI(cell,thread,18);
	return CoolingRate;
}
DEFINE_SOURCE(GranularDissipationFive, cell, thread, dS, eqn)
{
	real CoolingRate;
	CoolingRate = C_UDMI(cell,thread,19);
	return CoolingRate;
}

DEFINE_EXCHANGE_PROPERTY(C_D_one_two, cell, thread, column_one, column_two)
{
	real C_D;
	C_D = C_UDMI(cell,thread,25);
	return C_D;
}
DEFINE_EXCHANGE_PROPERTY(C_D_one_three, cell, thread, column_one, column_two)
{
	real C_D;
	C_D = C_UDMI(cell,thread,26);
	return C_D;
}
DEFINE_EXCHANGE_PROPERTY(C_D_one_four, cell, thread, column_one, column_two)
{
	real C_D;
	C_D = C_UDMI(cell,thread,27);
	return C_D;
}
DEFINE_EXCHANGE_PROPERTY(C_D_one_five, cell, thread, column_one, column_two)
{
	real C_D;
	C_D = C_UDMI(cell,thread,28);
	return C_D;
}

DEFINE_EXCHANGE_PROPERTY(C_D_two_three, cell, thread, column_one, column_two)
{
	real C_D;
	C_D = C_UDMI(cell,thread,29);
	return C_D;
}
DEFINE_EXCHANGE_PROPERTY(C_D_two_four, cell, thread, column_one, column_two)
{
	real C_D;
	C_D = C_UDMI(cell,thread,30);
	return C_D;
}
DEFINE_EXCHANGE_PROPERTY(C_D_two_five, cell, thread, column_one, column_two)
{
	real C_D;
	C_D = C_UDMI(cell,thread,31);
	return C_D;
}

DEFINE_EXCHANGE_PROPERTY(C_D_three_four, cell, thread, column_one, column_two)
{
	real C_D;
	C_D = C_UDMI(cell,thread,32);
	return C_D;
}
DEFINE_EXCHANGE_PROPERTY(C_D_three_five, cell, thread, column_one, column_two)
{
	real C_D;
	C_D = C_UDMI(cell,thread,33);
	return C_D;
}

DEFINE_EXCHANGE_PROPERTY(C_D_four_five, cell, thread, column_one, column_two)
{
	real C_D;
	C_D = C_UDMI(cell,thread,34);
	return C_D;
}

/***********************************************************************
   UDFs for Kellogg 2017 population balance 
(Hrenya Group via Kevin M. Kellogg)
************************************************************************/

/*User defined function for net mass per volume rate of creation of doublets.*/
DEFINE_SOURCE(NetSinglet, cell, thread, dS, eqn)
{
	real agg_rate;
	agg_rate=C_UDMI(cell,thread,51);
	return agg_rate;
}

DEFINE_SOURCE(NetDoublet, cell, thread, dS, eqn)
{
	real agg_rate;
	agg_rate=C_UDMI(cell,thread,52);
	return agg_rate;
}

DEFINE_SOURCE(NetTriplet, cell, thread, dS, eqn)
{
	real agg_rate;
	agg_rate=C_UDMI(cell,thread,53);
	return agg_rate;
}

DEFINE_SOURCE(NetQuadruplet, cell, thread, dS, eqn)
{
	real agg_rate;
	agg_rate=C_UDMI(cell,thread,54);
	return agg_rate;
}

DEFINE_SOURCE(NetQuintet, cell, thread, dS, eqn)
{
	real agg_rate;
	agg_rate=C_UDMI(cell,thread,55);
	return agg_rate;
}

/*User defined function for net momentum change due to aggregation/breakage*/
DEFINE_SOURCE(SingletXMomentum, cell, thread, dS, eqn)
{
	real MomentumChange;
	MomentumChange=C_UDMI(cell,thread,56);
	return MomentumChange;
}
DEFINE_SOURCE(SingletYMomentum, cell, thread, dS, eqn)
{
	real MomentumChange;
	MomentumChange=C_UDMI(cell,thread,57);
	return MomentumChange;
}
DEFINE_SOURCE(SingletZMomentum, cell, thread, dS, eqn)
{
	real MomentumChange;
	MomentumChange=C_UDMI(cell,thread,58);
	return MomentumChange;
}
DEFINE_SOURCE(DoubletXMomentum, cell, thread, dS, eqn)
{
	real MomentumChange;
	MomentumChange=C_UDMI(cell,thread,59);
	return MomentumChange;
}
DEFINE_SOURCE(DoubletYMomentum, cell, thread, dS, eqn)
{
	real MomentumChange;
	MomentumChange=C_UDMI(cell,thread,60);
	return MomentumChange;
}
DEFINE_SOURCE(DoubletZMomentum, cell, thread, dS, eqn)
{
	real MomentumChange;
	MomentumChange=C_UDMI(cell,thread,61);
	return MomentumChange;
}
DEFINE_SOURCE(TripletXMomentum, cell, thread, dS, eqn)
{
	real MomentumChange;
	MomentumChange=C_UDMI(cell,thread,62);
	return MomentumChange;
}
DEFINE_SOURCE(TripletYMomentum, cell, thread, dS, eqn)
{
	real MomentumChange;
	MomentumChange=C_UDMI(cell,thread,63);
	return MomentumChange;
}
DEFINE_SOURCE(TripletZMomentum, cell, thread, dS, eqn)
{
	real MomentumChange;
	MomentumChange=C_UDMI(cell,thread,64);
	return MomentumChange;
}
DEFINE_SOURCE(QuadrupletXMomentum, cell, thread, dS, eqn)
{
	real MomentumChange;
	MomentumChange=C_UDMI(cell,thread,65);
	return MomentumChange;
}
DEFINE_SOURCE(QuadrupletYMomentum, cell, thread, dS, eqn)
{
	real MomentumChange;
	MomentumChange=C_UDMI(cell,thread,66);
	return MomentumChange;
}
DEFINE_SOURCE(QuadrupletZMomentum, cell, thread, dS, eqn)
{
	real MomentumChange;
	MomentumChange=C_UDMI(cell,thread,67);
	return MomentumChange;
}
DEFINE_SOURCE(QuintetXMomentum, cell, thread, dS, eqn)
{
	real MomentumChange;
	MomentumChange=C_UDMI(cell,thread,68);
	return MomentumChange;
}
DEFINE_SOURCE(QuintetYMomentum, cell, thread, dS, eqn)
{
	real MomentumChange;
	MomentumChange=C_UDMI(cell,thread,69);
	return MomentumChange;
}
DEFINE_SOURCE(QuintetZMomentum, cell, thread, dS, eqn)
{
	real MomentumChange;
	MomentumChange=C_UDMI(cell,thread,70);
	return MomentumChange;
}


/***********************************************************************
UDSs for pressure drops with in multiphase flow when using periodic boundary conditions
(Hrenya Group via Kevin M. Kellogg)
************************************************************************/

/*User defined function for adding pressure drop to gas phase when using periodic boundary conditions for inlet and outlet.*/

DEFINE_SOURCE(Padd1,cell,thread,dS,eqn)
{ 	 
	real fP;
	Thread *mixture_thread = THREAD_SUPER_THREAD(thread);

	fP=(1.-C_UDMI(cell,mixture_thread,50))*dPdY;
	
	return fP;
}
DEFINE_SOURCE(Padd2,cell,thread,dS,eqn)
{ 	 
	real fP;
	Thread *mixture_thread = THREAD_SUPER_THREAD(thread);
	Thread *subthread_one = THREAD_SUB_THREAD(mixture_thread, ph_1_id);

	fP=C_VOF(cell,subthread_one)*dPdY;

	return fP;
}
DEFINE_SOURCE(Padd3,cell,thread,dS,eqn)
{ 	
	real fP;

	Thread *mixture_thread = THREAD_SUPER_THREAD(thread);
	Thread *subthread_two = THREAD_SUB_THREAD(mixture_thread, ph_2_id);

	fP=C_VOF(cell,subthread_two)*dPdY;	

	return fP;
}
DEFINE_SOURCE(Padd4,cell,thread,dS,eqn)
{ 	
	real fP;

	Thread *mixture_thread = THREAD_SUPER_THREAD(thread);
	Thread *subthread_three = THREAD_SUB_THREAD(mixture_thread, ph_3_id);

	fP=C_VOF(cell,subthread_three)*dPdY;	

	return fP;
}
DEFINE_SOURCE(Padd5,cell,thread,dS,eqn)
{ 	
	real fP;

	Thread *mixture_thread = THREAD_SUPER_THREAD(thread);
	Thread *subthread_four = THREAD_SUB_THREAD(mixture_thread, ph_4_id);

	fP=C_VOF(cell,subthread_four)*dPdY;	

	return fP;
}
DEFINE_SOURCE(Padd6,cell,thread,dS,eqn)
{ 	
	real fP;

	Thread *mixture_thread = THREAD_SUPER_THREAD(thread);
	Thread *subthread_five = THREAD_SUB_THREAD(mixture_thread, ph_5_id);

	fP=C_VOF(cell,subthread_five)*dPdY;	

	return fP;
}

/*******************************************************************************
User Defined Function for Koch-Hill drag law
(Kevin Kellogg via Hrenya Research Group)
Hook EXCHANGE_PROPERTY from:
Tree -> Models -> Multiphase -> Phases -> Phase Interactions -> Drag -> user-defined

*******************************************************************************/
DEFINE_EXCHANGE_PROPERTY(KGasSinglet,cell,mixture_thread,s_col,f_col)
{
real Beta, ReP, F, F0, F1, F2, F3, w, vfrac;
vfrac=C_UDMI(cell,mixture_thread,50);
Thread *gasthread=THREAD_SUB_THREAD(mixture_thread,s_col);
Thread *solthread=THREAD_SUB_THREAD(mixture_thread,f_col);

ReP=C_R(cell,gasthread)*(1.-C_VOF(cell,solthread))*d_one/(2.*C_MU_L(cell,gasthread))*sqrt((C_U(cell,solthread)-C_U(cell,gasthread))*(C_U(cell,solthread)-C_U(cell,gasthread))+(C_V(cell,solthread)-C_V(cell,gasthread))*(C_V(cell,solthread)-C_V(cell,gasthread))+(C_W(cell,solthread)-C_W(cell,gasthread))*(C_W(cell,solthread)-C_W(cell,gasthread)));

if (vfrac<=0.01){
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.9351*vfrac+0.03667;
	if(ReP<=(F2-1.)/(0.375-F3)){
		F=1.+0.375*ReP;
	}
	else {
		F=F2+F3*ReP;
	}
}
else if (vfrac<=0.0953) {
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F0=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.14*vfrac)/(1.+0.681*vfrac-8.48*vfrac*vfrac+8.16*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F1=0.025*sqrt(2./vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.9351*vfrac+0.03667;
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}
else if (vfrac<=0.1) {
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F0=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.14*vfrac)/(1.+0.681*vfrac-8.48*vfrac*vfrac+8.16*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F1=0.025*sqrt(2./vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.0673+0.212*vfrac+0.0232/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}
else if (vfrac<=0.4) {
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F0=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.14*vfrac)/(1.+0.681*vfrac-8.48*vfrac*vfrac+8.16*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F1=0.11+0.00051*exp(11.6*vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.0673+0.212*vfrac+0.0232/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}
else {
	F0=10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	F1=0.11+0.00051*exp(11.6*vfrac);
	F2=10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac));	
	F3=0.0673+0.212*vfrac+0.0232/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}

Beta=18.*C_MU_L(cell,gasthread)*(1.-C_VOF(cell,solthread))*(1.-C_VOF(cell,solthread))*C_VOF(cell,solthread)*F/(d_one*d_one);

return Beta;

}

DEFINE_EXCHANGE_PROPERTY(KGasDoublet,cell,mixture_thread,s_col,f_col)
{
real Beta, ReP, F, F0, F1, F2, F3, w, vfrac;
vfrac=C_UDMI(cell,mixture_thread,50);
Thread *gasthread=THREAD_SUB_THREAD(mixture_thread,s_col);
Thread *solthread=THREAD_SUB_THREAD(mixture_thread,f_col);

ReP=C_R(cell,gasthread)*(1.-C_VOF(cell,solthread))*d_two/(2.*C_MU_L(cell,gasthread))*sqrt((C_U(cell,solthread)-C_U(cell,gasthread))*(C_U(cell,solthread)-C_U(cell,gasthread))+(C_V(cell,solthread)-C_V(cell,gasthread))*(C_V(cell,solthread)-C_V(cell,gasthread))+(C_W(cell,solthread)-C_W(cell,gasthread))*(C_W(cell,solthread)-C_W(cell,gasthread)));

if (vfrac<=0.01){
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.9351*vfrac+0.03667;
	if(ReP<=(F2-1.)/(0.375-F3)){
		F=1.+0.375*ReP;
	}
	else {
		F=F2+F3*ReP;
	}
}
else if (vfrac<=0.0953) {
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F0=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.14*vfrac)/(1.+0.681*vfrac-8.48*vfrac*vfrac+8.16*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F1=0.025*sqrt(2./vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.9351*vfrac+0.03667;
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}
else if (vfrac<=0.1) {
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F0=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.14*vfrac)/(1.+0.681*vfrac-8.48*vfrac*vfrac+8.16*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F1=0.025*sqrt(2./vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.0673+0.212*vfrac+0.0232/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}
else if (vfrac<=0.4) {
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F0=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.14*vfrac)/(1.+0.681*vfrac-8.48*vfrac*vfrac+8.16*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F1=0.11+0.00051*exp(11.6*vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.0673+0.212*vfrac+0.0232/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}
else {
	F0=10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	F1=0.11+0.00051*exp(11.6*vfrac);
	F2=10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac));	
	F3=0.0673+0.212*vfrac+0.0232/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}

Beta=18.*C_MU_L(cell,gasthread)*(1.-C_VOF(cell,solthread))*(1.-C_VOF(cell,solthread))*C_VOF(cell,solthread)*F/(d_two*d_two);

return Beta;

}

DEFINE_EXCHANGE_PROPERTY(KGasTriplet,cell,mixture_thread,s_col,f_col)
{
real Beta, ReP, F, F0, F1, F2, F3, w, vfrac;
vfrac=C_UDMI(cell,mixture_thread,50);
Thread *gasthread=THREAD_SUB_THREAD(mixture_thread,s_col);
Thread *solthread=THREAD_SUB_THREAD(mixture_thread,f_col);

ReP=C_R(cell,gasthread)*(1.-C_VOF(cell,solthread))*d_three/(2.*C_MU_L(cell,gasthread))*sqrt((C_U(cell,solthread)-C_U(cell,gasthread))*(C_U(cell,solthread)-C_U(cell,gasthread))+(C_V(cell,solthread)-C_V(cell,gasthread))*(C_V(cell,solthread)-C_V(cell,gasthread))+(C_W(cell,solthread)-C_W(cell,gasthread))*(C_W(cell,solthread)-C_W(cell,gasthread)));

if (vfrac<=0.01){
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.9351*vfrac+0.03667;
	if(ReP<=(F2-1.)/(0.375-F3)){
		F=1.+0.375*ReP;
	}
	else {
		F=F2+F3*ReP;
	}
}
else if (vfrac<=0.0953) {
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F0=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.14*vfrac)/(1.+0.681*vfrac-8.48*vfrac*vfrac+8.16*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F1=0.025*sqrt(2./vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.9351*vfrac+0.03667;
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}
else if (vfrac<=0.1) {
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F0=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.14*vfrac)/(1.+0.681*vfrac-8.48*vfrac*vfrac+8.16*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F1=0.025*sqrt(2./vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.0673+0.212*vfrac+0.0232/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}
else if (vfrac<=0.4) {
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F0=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.14*vfrac)/(1.+0.681*vfrac-8.48*vfrac*vfrac+8.16*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F1=0.11+0.00051*exp(11.6*vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.0673+0.212*vfrac+0.0232/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}
else {
	F0=10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	F1=0.11+0.00051*exp(11.6*vfrac);
	F2=10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac));	
	F3=0.0673+0.212*vfrac+0.0232/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}

Beta=18.*C_MU_L(cell,gasthread)*(1.-C_VOF(cell,solthread))*(1.-C_VOF(cell,solthread))*C_VOF(cell,solthread)*F/(d_three*d_three);

return Beta;

}

DEFINE_EXCHANGE_PROPERTY(KGasQuadruplet,cell,mixture_thread,s_col,f_col)
{
real Beta, ReP, F, F0, F1, F2, F3, w, vfrac;
vfrac=C_UDMI(cell,mixture_thread,50);
Thread *gasthread=THREAD_SUB_THREAD(mixture_thread,s_col);
Thread *solthread=THREAD_SUB_THREAD(mixture_thread,f_col);

ReP=C_R(cell,gasthread)*(1.-C_VOF(cell,solthread))*d_four/(2.*C_MU_L(cell,gasthread))*sqrt((C_U(cell,solthread)-C_U(cell,gasthread))*(C_U(cell,solthread)-C_U(cell,gasthread))+(C_V(cell,solthread)-C_V(cell,gasthread))*(C_V(cell,solthread)-C_V(cell,gasthread))+(C_W(cell,solthread)-C_W(cell,gasthread))*(C_W(cell,solthread)-C_W(cell,gasthread)));

if (vfrac<=0.01){
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.9351*vfrac+0.03667;
	if(ReP<=(F2-1.)/(0.375-F3)){
		F=1.+0.375*ReP;
	}
	else {
		F=F2+F3*ReP;
	}
}
else if (vfrac<=0.0953) {
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F0=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.14*vfrac)/(1.+0.681*vfrac-8.48*vfrac*vfrac+8.16*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F1=0.025*sqrt(2./vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.9351*vfrac+0.03667;
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}
else if (vfrac<=0.1) {
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F0=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.14*vfrac)/(1.+0.681*vfrac-8.48*vfrac*vfrac+8.16*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F1=0.025*sqrt(2./vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.0673+0.212*vfrac+0.0232/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}
else if (vfrac<=0.4) {
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F0=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.14*vfrac)/(1.+0.681*vfrac-8.48*vfrac*vfrac+8.16*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F1=0.11+0.00051*exp(11.6*vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.0673+0.212*vfrac+0.0232/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}
else {
	F0=10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	F1=0.11+0.00051*exp(11.6*vfrac);
	F2=10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac));	
	F3=0.0673+0.212*vfrac+0.0232/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}

Beta=18.*C_MU_L(cell,gasthread)*(1.-C_VOF(cell,solthread))*(1.-C_VOF(cell,solthread))*C_VOF(cell,solthread)*F/(d_four*d_four);

return Beta;

}

DEFINE_EXCHANGE_PROPERTY(KGasQuintet,cell,mixture_thread,s_col,f_col)
{
real Beta, ReP, F, F0, F1, F2, F3, w, vfrac;
vfrac=C_UDMI(cell,mixture_thread,50);
Thread *gasthread=THREAD_SUB_THREAD(mixture_thread,s_col);
Thread *solthread=THREAD_SUB_THREAD(mixture_thread,f_col);

ReP=C_R(cell,gasthread)*(1.-C_VOF(cell,solthread))*d_five/(2.*C_MU_L(cell,gasthread))*sqrt((C_U(cell,solthread)-C_U(cell,gasthread))*(C_U(cell,solthread)-C_U(cell,gasthread))+(C_V(cell,solthread)-C_V(cell,gasthread))*(C_V(cell,solthread)-C_V(cell,gasthread))+(C_W(cell,solthread)-C_W(cell,gasthread))*(C_W(cell,solthread)-C_W(cell,gasthread)));

if (vfrac<=0.01){
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.9351*vfrac+0.03667;
	if(ReP<=(F2-1.)/(0.375-F3)){
		F=1.+0.375*ReP;
	}
	else {
		F=F2+F3*ReP;
	}
}
else if (vfrac<=0.0953) {
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F0=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.14*vfrac)/(1.+0.681*vfrac-8.48*vfrac*vfrac+8.16*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F1=0.025*sqrt(2./vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.9351*vfrac+0.03667;
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}
else if (vfrac<=0.1) {
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F0=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.14*vfrac)/(1.+0.681*vfrac-8.48*vfrac*vfrac+8.16*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F1=0.025*sqrt(2./vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.0673+0.212*vfrac+0.0232/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}
else if (vfrac<=0.4) {
	w=exp(-10.*(0.4-vfrac)/vfrac);
	F0=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.14*vfrac)/(1.+0.681*vfrac-8.48*vfrac*vfrac+8.16*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F1=0.11+0.00051*exp(11.6*vfrac);
	F2=(1.-w)*((1.+3.*sqrt(vfrac/2.)+135./64.*vfrac*log(vfrac)+17.89*vfrac)/(1.+0.681*vfrac-11.03*vfrac*vfrac+15.41*vfrac*vfrac*vfrac))+w*(10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)));
	F3=0.0673+0.212*vfrac+0.0232/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}
else {
	F0=10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	F1=0.11+0.00051*exp(11.6*vfrac);
	F2=10.*vfrac/((1.-vfrac)*(1.-vfrac)*(1.-vfrac));	
	F3=0.0673+0.212*vfrac+0.0232/((1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac)*(1.-vfrac));
	if (ReP<=(F3+sqrt(F3*F3-4.*F1*(F0-F2)))/(2.*F1)) {
		F=F0+F1*ReP*ReP;
	}
	else { 
		F=F2+F3*ReP;
	}
}

Beta=18.*C_MU_L(cell,gasthread)*(1.-C_VOF(cell,solthread))*(1.-C_VOF(cell,solthread))*C_VOF(cell,solthread)*F/(d_five*d_five);

return Beta;

}